@@ -23,7 +23,6 @@ from pickle import dump
 from locale import getlocale
 from gettext import gettext as _
 from threading import Thread
-import os
 
 
 try:
@@ -36,7 +35,7 @@ except Exception as e:
     print("$ sudo pip3 install pylast")
     LastFM = None
 
-from lollypop.utils import is_gnome, is_unity
+from lollypop.utils import is_gnome, is_unity, get_network_available
 from lollypop.define import Type, DataPath
 from lollypop.window import Window
 from lollypop.database import Database
@@ -68,8 +67,8 @@ class Application(Gtk.Application):
                             self,
                             application_id='org.gnome.Lollypop',
                             flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE)
-        os.environ['PULSE_PROP_media.role'] = 'music'
-        os.environ['PULSE_PROP_application.icon_name'] = 'lollypop'
+        GLib.setenv('PULSE_PROP_media.role', 'music', True)
+        GLib.setenv('PULSE_PROP_application.icon_name', 'lollypop', True)
         self.cursors = {}
         self.window = None
         self.notify = None
@@ -77,7 +76,7 @@ class Application(Gtk.Application):
         self.debug = False
         self.__externals_count = 0
         self.__init_proxy()
-        GLib.set_application_name('lollypop')
+        GLib.set_application_name('Lollypop')
         GLib.set_prgname('lollypop')
         # TODO: Remove this test later
         if Gtk.get_minor_version() > 12:
@@ -159,6 +158,7 @@ class Application(Gtk.Application):
         self.__parser = TotemPlParser.Parser.new()
         self.__parser.connect('entry-parsed', self.__on_entry_parsed)
 
+        self.add_action(self.settings.create_action('playback'))
         self.add_action(self.settings.create_action('shuffle'))
 
         self.db.upgrade()
@@ -184,7 +184,7 @@ class Application(Gtk.Application):
             # If GNOME/Unity, add appmenu
             if is_gnome() or is_unity():
                 self.set_app_menu(menu)
-            self.window = Window(self)
+            self.window = Window()
             # If not GNOME/Unity add menu to toolbar
             if not is_gnome() and not is_unity():
                 self.window.setup_menu(menu)
@@ -204,18 +204,19 @@ class Application(Gtk.Application):
                 from lollypop.inhibitor_legacy import Inhibitor
             self.inhibitor = Inhibitor()
             self.charts = None
-            if self.settings.get_value('network-search'):
-                from shutil import which
-                if which("youtube-dl") is not None:
+            if self.settings.get_value('show-charts'):
+                if GLib.find_program_in_path("youtube-dl") is not None:
                     from lollypop.charts import Charts
                     self.charts = Charts()
-                    self.charts.update()
+                    if get_network_available():
+                        self.charts.update()
                     cs_api_key = self.settings.get_value(
                                                      'cs-api-key').get_string()
                     default_cs_api_key = self.settings.get_default_value(
                                                      'cs-api-key').get_string()
                     if (not cs_api_key or
                         cs_api_key == default_cs_api_key) and\
+                            get_network_available() and\
                             self.notify is not None:
                         self.notify.send(
                          _("Google Web Services need a custom API key"),
@@ -321,7 +322,8 @@ class Application(Gtk.Application):
             h = settings.get_value('host').get_string()
             p = settings.get_value('port').get_int32()
             if h != '' and p != 0:
-                os.environ['HTTP_PROXY'] = "%s:%s" % (h, p)
+                GLib.setenv('http_proxy', "%s:%s" % (h, p), True)
+                GLib.setenv('https_proxy', "%s:%s" % (h, p), True)
         except:
             pass
 
@@ -383,7 +385,8 @@ class Application(Gtk.Application):
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
-        if not self.settings.get_value('background-mode'):
+        if not self.settings.get_value('background-mode') or\
+                self.player.current_track.id is None:
             GLib.timeout_add(500, self.prepare_to_exit)
             self.scanner.stop()
         return widget.hide_on_delete()
@@ -400,6 +403,21 @@ class Application(Gtk.Application):
             t.start()
             self.window.update_db()
 
+    def __set_network(self, action, param):
+        """
+            Enable/disable network
+            @param action as Gio.SimpleAction
+            @param param as GLib.Variant
+        """
+        action.set_state(param)
+        self.settings.set_value('network-access', param)
+        if self.charts is not None:
+            if param.get_boolean():
+                self.charts.update()
+            else:
+                self.charts.stop()
+        self.window.reload_view()
+
     def __fullscreen(self, action=None, param=None):
         """
             Show a fullscreen window with cover and artist informations
@@ -495,42 +513,41 @@ class Application(Gtk.Application):
 
         settingsAction = Gio.SimpleAction.new('settings', None)
         settingsAction.connect('activate', self.__settings_dialog)
-        self.set_accels_for_action('app.settings', ["<Control>s"])
         self.add_action(settingsAction)
 
         updateAction = Gio.SimpleAction.new('update_db', None)
         updateAction.connect('activate', self.__update_db)
-        self.set_accels_for_action('app.update_db', ["<Control>u"])
         self.add_action(updateAction)
 
+        networkAction = Gio.SimpleAction.new_stateful(
+           'network',
+           None,
+           GLib.Variant.new_boolean(self.settings.get_value('network-access')))
+        networkAction.connect('change-state', self.__set_network)
+        self.add_action(networkAction)
+
         fsAction = Gio.SimpleAction.new('fullscreen', None)
         fsAction.connect('activate', self.__fullscreen)
-        self.set_accels_for_action('app.fullscreen', ["F11", "F7"])
         self.add_action(fsAction)
 
         mini_action = Gio.SimpleAction.new('mini', None)
         mini_action.connect('activate', self.set_mini)
         self.add_action(mini_action)
-        self.set_accels_for_action("app.mini", ["<Control>m"])
 
         aboutAction = Gio.SimpleAction.new('about', None)
         aboutAction.connect('activate', self.__about)
-        self.set_accels_for_action('app.about', ["F3"])
         self.add_action(aboutAction)
 
         shortcutsAction = Gio.SimpleAction.new('shortcuts', None)
         shortcutsAction.connect('activate', self.__shortcuts)
-        self.set_accels_for_action('app.shortcuts', ["F2"])
         self.add_action(shortcutsAction)
 
         helpAction = Gio.SimpleAction.new('help', None)
         helpAction.connect('activate', self.__help)
-        self.set_accels_for_action('app.help', ["F1"])
         self.add_action(helpAction)
 
         quitAction = Gio.SimpleAction.new('quit', None)
         quitAction.connect('activate', self.prepare_to_exit)
-        self.set_accels_for_action('app.quit', ["<Control>q"])
         self.add_action(quitAction)
 
         return menu
