@@ -17,6 +17,7 @@ from gettext import gettext as _
 
 from lollypop.cache import InfoCache
 from lollypop.define import Lp, ArtSize
+from lollypop.utils import get_network_available
 
 
 class ArtworkSearch(Gtk.Bin):
@@ -85,10 +86,10 @@ class ArtworkSearch(Gtk.Bin):
 
         # First load local files
         if self.__album is not None:
-            paths = Lp().art.get_album_artworks(self.__album)
-            for path in paths:
+            uris = Lp().art.get_album_artworks(self.__album)
+            for uri in uris:
                 try:
-                    f = Gio.File.new_for_path(path)
+                    f = Gio.File.new_for_uri(uri)
                     (status, data, tag) = f.load_contents()
                     self.__add_pixbuf(data)
                 except Exception as e:
@@ -204,7 +205,7 @@ class ArtworkSearch(Gtk.Bin):
             @thread safe
         """
         urls = []
-        if Gio.NetworkMonitor.get_default().get_network_available():
+        if get_network_available():
             if search != "":
                 urls = Lp().art.get_google_arts(search)
             elif self.__album is not None:
@@ -219,10 +220,12 @@ class ArtworkSearch(Gtk.Bin):
                                                                  self.__artist,
                                                                  genre))
                 urls += Lp().art.get_google_arts(self.__artist)
-        if urls:
-            self.__add_pixbufs(urls, search)
+            if urls:
+                self.__add_pixbufs(urls, search)
+            else:
+                GLib.idle_add(self.__show_not_found)
         else:
-            GLib.idle_add(self.__show_not_found)
+            GLib.idle_add(self._spinner.stop)
 
     def __add_pixbufs(self, urls, search):
         """
