@@ -12,7 +12,7 @@
 
 from gi.repository import Gio, GdkPixbuf
 
-from os import mkdir, path
+from os import mkdir, path, rename
 
 from lollypop.utils import escape
 from lollypop.define import ArtSize
@@ -22,34 +22,59 @@ class InfoCache:
     """
         Generic class to cache text and images
     """
-    CACHE_PATH = path.expanduser("~") + "/.cache/lollypop_info"
+    _INFO_PATH = path.expanduser("~") + "/.local/share/lollypop/info"
+    _CACHE_PATH = path.expanduser("~") + "/.cache/lollypop_info"
+    WEBSERVICES = [("lastfm", "_get_lastfm_artist_info",
+                    "_get_lastfm_album_artwork"),
+                   ("spotify", "_get_spotify_artist_info",
+                    "_get_spotify_album_artwork"),
+                   ("deezer", "_get_deezer_artist_info",
+                    "_get_deezer_album_artwork"),
+                   ("wikipedia", "_get_wp_artist_info",
+                    None)]
 
     def init():
         """
             Init cache
         """
-        if not path.exists(InfoCache.CACHE_PATH):
+        if not path.exists(InfoCache._INFO_PATH):
             try:
-                mkdir(InfoCache.CACHE_PATH)
+                mkdir(InfoCache._INFO_PATH)
             except:
-                print("Can't create %s" % InfoCache.CACHE_PATH)
+                print("Can't create %s" % InfoCache._INFO_PATH)
+        if not path.exists(InfoCache._CACHE_PATH):
+            try:
+                mkdir(InfoCache._CACHE_PATH)
+            except:
+                print("Can't create %s" % InfoCache._CACHE_PATH)
 
-    def exists_in_cache(prefix):
+    def exists(prefix):
         """
             Return True if an info is cached
             @param prefix as string
         """
         exists = False
-        for suffix in ["lastfm", "wikipedia", "spotify"]:
-            filepath = "%s/%s_%s_%s.jpg" % (InfoCache.CACHE_PATH,
-                                            escape(prefix),
-                                            suffix,
-                                            ArtSize.ARTIST)
+        for (suffix, helper1, helper2) in InfoCache.WEBSERVICES:
+            filepath = "%s/%s_%s.jpg" % (InfoCache._INFO_PATH,
+                                         escape(prefix),
+                                         suffix)
             if path.exists(filepath):
                 exists = True
+            else:
+                # FIXME Remove this code, support for old lollypop versions
+                #
+                old_path = "%s/%s_%s_%s.jpg" % (InfoCache._CACHE_PATH,
+                                                escape(prefix),
+                                                suffix,
+                                                ArtSize.ARTIST)
+                if path.exists(old_path):
+                    rename(old_path, filepath)
+                    exists = True
+                #
+                ##########################################################
         return exists
 
-    def get_artwork(prefix, suffix, size=ArtSize.ARTIST):
+    def get_artwork(prefix, suffix, size):
         """
             Return path for artwork
             @param prefix as string
@@ -58,61 +83,64 @@ class InfoCache:
             @return path as string/None
         """
         try:
-            extract = None
-            filepath = "%s/%s_%s_%s.jpg" % (InfoCache.CACHE_PATH,
-                                            escape(prefix),
-                                            suffix,
-                                            ArtSize.ARTIST)
-            filepath_at_size = "%s/%s_%s_%s.jpg" % (InfoCache.CACHE_PATH,
-                                                    escape(prefix),
-                                                    suffix,
-                                                    size)
-            if not path.exists(filepath) or path.getsize(filepath) == 0:
-                return None
-            # Make cache for this size
-            if not path.exists(filepath_at_size):
-                pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(filepath,
-                                                                size,
-                                                                size)
-                if pixbuf.get_height() > pixbuf.get_width():
-                    vertical = True
-                elif pixbuf.get_height() < pixbuf.get_width():
-                    vertical = False
-                else:
-                    extract = pixbuf
-                if extract is None:
-                    del pixbuf
-                    extract = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB,
-                                                   True, 8,
-                                                   size, size)
-                    if vertical:
-                        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
-                                                                      filepath,
-                                                                      size,
-                                                                      -1,
-                                                                      True)
-                        diff = pixbuf.get_height() - size
-                        pixbuf.copy_area(0, diff/2,
-                                         pixbuf.get_width(),
-                                         size,
-                                         extract,
-                                         0, 0)
+            for (suffix, helper1, helper2) in InfoCache.WEBSERVICES:
+                extract = None
+                filepath = "%s/%s_%s.jpg" % (InfoCache._INFO_PATH,
+                                             escape(prefix),
+                                             suffix)
+                filepath_at_size = "%s/%s_%s_%s.jpg" % (InfoCache._CACHE_PATH,
+                                                        escape(prefix),
+                                                        suffix,
+                                                        size)
+                if not path.exists(filepath) or path.getsize(filepath) == 0:
+                    filepath_at_size = None
+                    continue
+                # Make cache for this size
+                if not path.exists(filepath_at_size):
+                    pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(filepath,
+                                                                    size,
+                                                                    size)
+                    if pixbuf.get_height() > pixbuf.get_width():
+                        vertical = True
+                    elif pixbuf.get_height() < pixbuf.get_width():
+                        vertical = False
                     else:
-                        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
+                        extract = pixbuf
+                    if extract is None:
+                        del pixbuf
+                        extract = GdkPixbuf.Pixbuf.new(
+                                                    GdkPixbuf.Colorspace.RGB,
+                                                    True, 8,
+                                                    size, size)
+                        if vertical:
+                            pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
+                                                                      filepath,
+                                                                      size,
+                                                                      -1,
+                                                                      True)
+                            diff = pixbuf.get_height() - size
+                            pixbuf.copy_area(0, diff/2,
+                                             pixbuf.get_width(),
+                                             size,
+                                             extract,
+                                             0, 0)
+                        else:
+                            pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
                                                                       filepath,
                                                                       -1,
                                                                       size,
                                                                       True)
-                        diff = pixbuf.get_width() - size
-                        pixbuf.copy_area(diff/2, 0,
-                                         size,
-                                         pixbuf.get_height(),
-                                         extract,
-                                         0, 0)
-                    del pixbuf
-                extract.savev(filepath_at_size, "jpeg", ["quality"], ["90"])
-                del extract
-            return filepath_at_size
+                            diff = pixbuf.get_width() - size
+                            pixbuf.copy_area(diff/2, 0,
+                                             size,
+                                             pixbuf.get_height(),
+                                             extract,
+                                             0, 0)
+                        del pixbuf
+                    extract.savev(filepath_at_size, "jpeg",
+                                  ["quality"], ["90"])
+                    del extract
+                return filepath_at_size
         except Exception as e:
             print("InfoCache::get_artwork():", e)
             return None
@@ -124,7 +152,7 @@ class InfoCache:
             @param suffix as str
             @return (content as string, data as bytes)
         """
-        filepath = "%s/%s_%s" % (InfoCache.CACHE_PATH,
+        filepath = "%s/%s_%s" % (InfoCache._INFO_PATH,
                                  escape(prefix),
                                  suffix)
         content = None
@@ -134,7 +162,7 @@ class InfoCache:
             (status, content, tag) = f.load_contents()
             if not status:
                 content = None
-            image_path = filepath+"_"+str(ArtSize.ARTIST)+".jpg"
+            image_path = filepath+".jpg"
             if path.exists(image_path):
                 f = Gio.File.new_for_path(image_path)
                 (status, data, tag) = f.load_contents()
@@ -142,15 +170,15 @@ class InfoCache:
                     data = None
         return (content, data)
 
-    def cache(prefix, content, data, suffix):
+    def add(prefix, content, data, suffix):
         """
-            Cache datas
+            Add info to store
             @param prefix as str
             @param content as str
             @param data as bytes
             @param suffix as str
         """
-        filepath = "%s/%s_%s" % (InfoCache.CACHE_PATH,
+        filepath = "%s/%s_%s" % (InfoCache._INFO_PATH,
                                  escape(prefix),
                                  suffix)
         if content is not None:
@@ -161,7 +189,7 @@ class InfoCache:
                 fstream.write(content, None)
                 fstream.close()
         if data is None:
-            f = Gio.File.new_for_path(filepath+"_"+str(ArtSize.ARTIST)+".jpg")
+            f = Gio.File.new_for_path(filepath+".jpg")
             fstream = f.replace(None, False,
                                 Gio.FileCreateFlags.REPLACE_DESTINATION, None)
             fstream.close()
@@ -172,17 +200,17 @@ class InfoCache:
                                                                -1,
                                                                True,
                                                                None)
-            pixbuf.savev(filepath+"_"+str(ArtSize.ARTIST)+".jpg",
+            pixbuf.savev(filepath+".jpg",
                          "jpeg", ["quality"], ["90"])
             del pixbuf
 
-    def uncache(prefix, suffix):
+    def remove(prefix, suffix):
         """
-            Remove info from cache
+            Remove info from store
             @param prefix as str
             @param suffix as str
         """
-        filepath = "%s/%s_%s.txt" % (InfoCache.CACHE_PATH,
+        filepath = "%s/%s_%s.txt" % (InfoCache._INFO_PATH,
                                      escape(prefix),
                                      suffix)
         f = Gio.File.new_for_path(filepath)
@@ -190,10 +218,9 @@ class InfoCache:
             f.delete(None)
         except:
             pass
-        filepath = "%s/%s_%s_%s.jpg" % (InfoCache.CACHE_PATH,
-                                        escape(prefix),
-                                        suffix,
-                                        ArtSize.ARTIST)
+        filepath = "%s/%s_%s.jpg" % (InfoCache._INFO_PATH,
+                                     escape(prefix),
+                                     suffix)
         f = Gio.File.new_for_path(filepath)
         try:
             f.delete(None)
@@ -202,13 +229,13 @@ class InfoCache:
 
     def uncache_artwork(prefix, suffix, scale):
         """
-            Remove info from cache
+            Remove artwork from cache
             @param prefix as str
             @param suffix as str
             @param scale factor as int
         """
         for i in [1, 2]:
-            filepath = "%s/%s_%s_%s.jpg" % (InfoCache.CACHE_PATH,
+            filepath = "%s/%s_%s_%s.jpg" % (InfoCache._CACHE_PATH,
                                             escape(prefix),
                                             suffix,
                                             ArtSize.ARTIST_SMALL*scale*i)
