@@ -22,7 +22,7 @@ from locale import getdefaultlocale
 
 from lollypop.youtube import Youtube
 from lollypop.define import DbPersistent, Lp
-from lollypop.utils import debug
+from lollypop.utils import debug, get_network_available
 from lollypop.search_item import SearchItem
 
 
@@ -140,6 +140,7 @@ class ItunesCharts:
             Update charts
         """
         self.__stop = False
+        self.__cancel.reset()
         self.__count = self.__get_album_count()
         t = Thread(target=self.__update)
         t.daemon = True
@@ -185,7 +186,7 @@ class ItunesCharts:
             Update charts for url
             @param url as str
         """
-        if not Gio.NetworkMonitor.get_default().get_network_available():
+        if not get_network_available():
                 return
         debug("ItunesCharts::__update_for_url(): %s => %s" % (url,
                                                               self.__count))
@@ -195,10 +196,10 @@ class ItunesCharts:
             sleep(10)
             itunes_id = ids.pop(0)
             album = self.__get_album(itunes_id)
-            if album is None or album.exists_in_db():
-                continue
             if self.__stop:
                 return
+            if album is None or album.exists_in_db():
+                continue
             Lp().db.del_tracks(Lp().tracks.get_old_from_charts(self.__count))
             debug("ItunesCharts::__update_for_url(): %s - %s" % (
                                                                 album.name,
@@ -211,7 +212,7 @@ class ItunesCharts:
             @param id as int
             @return SearchItem/None
         """
-        if not Gio.NetworkMonitor.get_default().get_network_available():
+        if not get_network_available():
                 return
         language = getdefaultlocale()[0][0:2]
         try:
