@@ -120,7 +120,7 @@ class Container:
         view.show()
         self.__stack.add(view)
         self.__stack.set_visible_child(view)
-        current.disable_overlays()
+        current.disable_overlay()
 
     def show_playlist_editor(self, playlist_id):
         """
@@ -137,13 +137,6 @@ class Container:
         self.__stack.clean_old_views(view)
         view.populate()
 
-    def main_widget(self):
-        """
-            Get main widget
-            @return Gtk.HPaned
-        """
-        return self._paned_main_list
-
     def get_view_width(self):
         """
             Return view width
@@ -182,21 +175,36 @@ class Container:
                 self.__stack.clean_old_views(child)
                 break
 
-    def disable_overlays(self):
+    @property
+    def view(self):
         """
             Disable overlays
         """
-        view = self.__stack.get_visible_child()
-        if view:
-            view.disable_overlays()
+        return self.__stack.get_visible_child()
 
-    def update_view(self):
+    @property
+    def progress(self):
         """
-            Update current view
+            Progress bar
+            @return ProgressBar
         """
-        view = self.__stack.get_visible_child()
-        if view:
-            view.update_children()
+        return self.__progress
+
+    def add_remove_from(self, value, list_one, add):
+        """
+            Add or remove value to list
+            @param value as (int, str)
+            @param list one as bool
+            @param add as bool
+        """
+        if list_one:
+            l = self.__list_one
+        else:
+            l = self.__list_two
+        if add:
+            l.add_value(value)
+        else:
+            l.remove_value(value[0])
 
     def reload_view(self):
         """
@@ -248,11 +256,11 @@ class Container:
         dev.name = "Android phone"
         dev.uri = "file:///tmp/android/"
         d = Gio.File.new_for_uri(dev.uri+"Internal Memory")
-        if not d.query_exists(None):
-            d.make_directory_with_parents(None)
+        if not d.query_exists():
+            d.make_directory_with_parents()
         d = Gio.File.new_for_uri(dev.uri+"SD Card")
-        if not d.query_exists(None):
-            d.make_directory_with_parents(None)
+        if not d.query_exists():
+            d.make_directory_with_parents()
         self.__devices[self.__devices_index] = dev
 
     def show_artists_albums(self, artist_ids):
@@ -263,14 +271,6 @@ class Container:
         GLib.idle_add(self.__list_two.hide)
         GLib.idle_add(self.__list_one.select_ids, [])
 
-    @property
-    def progress(self):
-        """
-            Progress bar
-            @return ProgressBar
-        """
-        return self.__progress
-
 ############
 # Private  #
 ############
