@@ -10,15 +10,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib
-
 from gettext import gettext as _
-import os
 import itertools
 
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import Lp, Type, OrderBy
 from lollypop.utils import remove_static_genres, noaccents
+from lollypop.utils import get_network_available
 
 
 class AlbumsDatabase:
@@ -32,12 +30,12 @@ class AlbumsDatabase:
         """
         self._cached_randoms = []
 
-    def add(self, name, artist_ids, path, popularity, mtime):
+    def add(self, name, artist_ids, uri, popularity, mtime):
         """
             Add a new album to database
             @param Album name as string
             @param artist ids as int
-            @param path as string
+            @param uri as string
             @param mtime as int
             @return inserted rowid as int
             @warning: commit needed
@@ -45,10 +43,10 @@ class AlbumsDatabase:
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("INSERT INTO albums\
                                   (name, no_album_artist,\
-                                  path, popularity, mtime, synced)\
+                                  uri, popularity, mtime, synced)\
                                   VALUES (?, ?, ?, ?, ?, ?)",
                                  (name, artist_ids == [],
-                                  path, popularity, mtime, 0))
+                                  uri, popularity, mtime, 0))
             for artist_id in artist_ids:
                 sql.execute("INSERT INTO album_artists\
                              (album_id, artist_id)\
@@ -132,15 +130,15 @@ class AlbumsDatabase:
             sql.execute("UPDATE albums SET year=? WHERE rowid=?",
                         (year, album_id))
 
-    def set_path(self, album_id, path):
+    def set_uri(self, album_id, uri):
         """
-            Set album path for album id
-            @param Album id as int, path as string
+            Set album uri for album id
+            @param Album id as int, uri as string
             @warning: commit needed
         """
         with SqlCursor(Lp().db) as sql:
-            sql.execute("UPDATE albums SET path=? WHERE rowid=?",
-                        (path, album_id))
+            sql.execute("UPDATE albums SET uri=? WHERE rowid=?",
+                        (uri, album_id))
 
     def set_popularity(self, album_id, popularity, commit=False):
         """
@@ -246,44 +244,43 @@ class AlbumsDatabase:
                 return v[0]
             return 5
 
-    def get_non_compilation_id(self, album_name, artist_ids):
+    def get_id(self, album_name, artist_ids, remote):
         """
             Get non compilation album id
             @param Album name as string,
             @param artist ids as [int]
+            @param remote as bool
             @return Album id as int
         """
         with SqlCursor(Lp().db) as sql:
             filters = (album_name,)
-            filters += tuple(artist_ids)
-            request = "SELECT albums.rowid FROM albums, album_artists\
-                       WHERE name=? AND\
-                       no_album_artist=0 AND\
-                       album_artists.album_id=albums.rowid AND (1=0 "
-            for artist_id in artist_ids:
-                request += "OR artist_id=? "
-            request += ")"
+            if artist_ids:
+                filters += tuple(artist_ids)
+                request = "SELECT albums.rowid FROM albums, album_artists\
+                           WHERE name=? AND\
+                           no_album_artist=0 AND\
+                           album_artists.album_id=albums.rowid AND (1=0 "
+                for artist_id in artist_ids:
+                    request += "OR artist_id=? "
+                request += ")"
+                if remote:
+                    request += " AND synced=%s" % Type.NONE
+                else:
+                    request += " AND synced!=%s" % Type.NONE
+            else:
+                request = "SELECT rowid FROM albums\
+                           WHERE name=?\
+                           AND no_album_artist=1"
+                if remote:
+                    request += " AND synced=%s" % Type.NONE
+                else:
+                    request += " AND synced!=%s" % Type.NONE
             result = sql.execute(request, filters)
             v = result.fetchone()
             if v is not None:
                 return v[0]
             return None
 
-    def get_compilation_id(self, album_name):
-        """
-            Get compilation id
-            @param Album name as string,
-            @param year as int
-            @return Album id as int
-        """
-        with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid FROM albums where name=?\
-                                  AND no_album_artist=1", (album_name,))
-            v = result.fetchone()
-            if v is not None:
-                return v[0]
-            return None
-
     def get_year_from_tracks(self, album_id):
         """
             Get album year based on tracks
@@ -369,38 +366,28 @@ class AlbumsDatabase:
                 return str(v[0])
             return ""
 
-    def get_path(self, album_id):
+    def get_uri(self, album_id):
         """
-            Get album path for album id
+            Get album uri for album id
             @param Album id as int
-            @return Album path as string
+            @return Album uri as string
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT path FROM albums WHERE rowid=?",
+            result = sql.execute("SELECT uri FROM albums WHERE rowid=?",
                                  (album_id,))
-            path = ""
+            uri = ""
             v = result.fetchone()
             if v is not None:
-                path = v[0]
-            if path != "" and not os.path.exists(path):
-                tracks = self.get_track_ids(album_id, [], [])
-                if tracks:
-                    uri = Lp().tracks.get_uri(tracks[0])
-                    filepath = GLib.filename_from_uri(uri)[0]
-                    path = os.path.dirname(filepath)
-                    if os.path.exists(path):
-                        sql.execute("UPDATE albums SET path=? "
-                                    "WHERE rowid=?", (path, album_id))
-                        sql.commit()
-            return path
+                uri = v[0]
+            return uri
 
-    def get_path_count(self, path):
+    def get_uri_count(self, uri):
         """
-            Count album having path as album path
+            Count album having uri as album uri
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT count(path) FROM albums WHERE path=?",
-                                 (path,))
+            result = sql.execute("SELECT count(uri) FROM albums WHERE uri=?",
+                                 (uri,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
@@ -412,13 +399,15 @@ class AlbumsDatabase:
             @return array of album ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT DISTINCT albums.rowid\
-                                  FROM albums, album_genres\
-                                  WHERE popularity!=0\
-                                  AND album_genres.genre_id!=?\
-                                  AND album_genres.album_id=albums.rowid\
-                                  ORDER BY popularity DESC LIMIT 100",
-                                 (Type.CHARTS,))
+            filters = (Type.CHARTS, )
+            request = "SELECT DISTINCT albums.rowid\
+                       FROM albums, album_genres\
+                       WHERE album_genres.genre_id!=?\
+                       AND album_genres.album_id=albums.rowid"
+            if not get_network_available():
+                request += " AND albums.synced!=%s" % Type.NONE
+            request += " ORDER BY popularity DESC LIMIT 100"
+            result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
     def get_recents(self):
@@ -427,12 +416,15 @@ class AlbumsDatabase:
             @return array of albums ids as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT DISTINCT albums.rowid\
-                                  FROM albums, album_genres\
-                                  WHERE album_genres.genre_id!=?\
-                                  AND album_genres.album_id=albums.rowid\
-                                  ORDER BY mtime DESC LIMIT 100",
-                                 (Type.CHARTS,))
+            filters = (Type.CHARTS, )
+            request = "SELECT DISTINCT albums.rowid\
+                       FROM albums, album_genres\
+                       WHERE album_genres.genre_id!=?\
+                       AND album_genres.album_id=albums.rowid"
+            if not get_network_available():
+                request += " AND albums.synced!=%s" % Type.NONE
+            request += " ORDER BY mtime DESC LIMIT 100"
+            result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
     def get_randoms(self):
@@ -442,13 +434,15 @@ class AlbumsDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             albums = []
-
-            result = sql.execute("SELECT DISTINCT albums.rowid\
-                                  FROM albums, album_genres\
-                                  WHERE album_genres.genre_id!=?\
-                                  AND album_genres.album_id=albums.rowid\
-                                  ORDER BY random() LIMIT 100",
-                                 (Type.CHARTS,))
+            filters = (Type.CHARTS, )
+            request = "SELECT DISTINCT albums.rowid\
+                       FROM albums, album_genres\
+                       WHERE album_genres.genre_id!=?\
+                       AND album_genres.album_id=albums.rowid"
+            if not get_network_available():
+                request += " AND albums.synced!=%s" % Type.NONE
+            request += " ORDER BY random() LIMIT 100"
+            result = sql.execute(request, filters)
             albums = list(itertools.chain(*result))
             self._cached_randoms = list(albums)
             return albums
@@ -654,22 +648,22 @@ class AlbumsDatabase:
         genre_ids = remove_static_genres(genre_ids)
         orderby = Lp().settings.get_enum('orderby')
         if genre_ids and genre_ids[0] == Type.CHARTS:
-            order = "ORDER BY albums.id DESC"
+            order = " ORDER BY albums.id DESC"
         elif orderby == OrderBy.ARTIST:
-            order = "ORDER BY artists.sortname\
+            order = " ORDER BY artists.sortname\
                      COLLATE NOCASE COLLATE LOCALIZED,\
                      albums.year,\
                      albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
         elif orderby == OrderBy.NAME:
-            order = "ORDER BY albums.name\
+            order = " ORDER BY albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
         elif orderby == OrderBy.YEAR:
-            order = "ORDER BY albums.year,\
+            order = " ORDER BY albums.year,\
                      albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
         else:
-            order = "ORDER BY albums.popularity DESC,\
+            order = " ORDER BY albums.popularity DESC,\
                      albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
 
@@ -683,8 +677,10 @@ class AlbumsDatabase:
                            WHERE artists.rowid=album_artists.artist_id\
                            AND album_genres.genre_id!=?\
                            AND album_genres.album_id=albums.rowid\
-                           AND albums.rowid=album_artists.album_id\
-                           %s" % order
+                           AND albums.rowid=album_artists.album_id"
+                if not get_network_available():
+                    request += " AND albums.synced!=%s" % Type.NONE
+                request += order
                 result = sql.execute(request, filters)
             # Get albums for genre
             elif not artist_ids:
@@ -696,7 +692,10 @@ class AlbumsDatabase:
                            AND album_genres.album_id=albums.rowid AND ("
                 for genre_id in genre_ids:
                     request += "album_genres.genre_id=? OR "
-                request += "1=0) %s" % order
+                request += "1=0)"
+                if not get_network_available():
+                    request += " AND albums.synced!=%s" % Type.NONE
+                request += order
                 result = sql.execute(request, filters)
             # Get albums for artist
             elif not genre_ids:
@@ -710,7 +709,10 @@ class AlbumsDatabase:
                            AND album_artists.album_id=albums.rowid AND ("
                 for artist_id in artist_ids:
                     request += "album_artists.artist_id=? OR "
-                request += "1=0) %s" % order
+                request += "1=0)"
+                if not get_network_available():
+                    request += " AND albums.synced!=%s" % Type.NONE
+                request += order
                 result = sql.execute(request, filters)
             # Get albums for artist id and genre id
             else:
@@ -726,7 +728,10 @@ class AlbumsDatabase:
                 request += "1=0) AND ("
                 for genre_id in genre_ids:
                     request += "album_genres.genre_id=? OR "
-                request += "1=0) %s" % order
+                request += "1=0)"
+                if not get_network_available():
+                    request += " AND albums.synced!=%s" % Type.NONE
+                request += order
                 result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
