@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gst, GstAudio, GstPbutils, GLib, Gio
+from gi.repository import Gst, GstAudio, GstPbutils, GLib
 
 from time import time
 from threading import Thread
@@ -22,7 +22,7 @@ from lollypop.player_plugins import PluginsPlayer
 from lollypop.define import GstPlayFlags, NextContext, Lp
 from lollypop.codecs import Codecs
 from lollypop.define import Type, DbPersistent
-from lollypop.utils import debug
+from lollypop.utils import debug, get_network_available
 from lollypop.objects import Track
 
 
@@ -272,7 +272,7 @@ class BinPlayer(BasePlayer):
             @param play as bool
             @return True if loading
         """
-        if not Gio.NetworkMonitor.get_default().get_network_available():
+        if not get_network_available():
             # Force widgets to update (spinners)
             self.emit('current-changed')
             return False
@@ -461,11 +461,15 @@ class BinPlayer(BasePlayer):
             @return bool
         """
         stop = False
-        if self._context.next != NextContext.NONE:
+        playback = Lp().settings.get_enum('playback')
+        if playback not in [NextContext.NONE, NextContext.REPEAT_TRACK]:
             # Stop if needed
-            if self._context.next == NextContext.STOP_TRACK:
+            if Lp().settings.get_enum('playback') == NextContext.STOP_TRACK:
                 stop = True
-            elif self._context.next == self._finished:
+                Lp().settings.set_enum('playback', NextContext.NONE)
+            elif self._next_context == NextContext.STOP_ALL:
+                stop = True
+            elif Lp().settings.get_enum('playback') == self._next_context:
                 stop = True
         return stop and self.is_playing()
 
@@ -532,12 +536,6 @@ class BinPlayer(BasePlayer):
                                                                   0)[1]
             if self.current_track.album_name is None:
                 self.current_track.album_name = ''
-            self.current_track.artists = reader.get_artists(tags).split(',')
-            self.current_track.set_album_artists(
-                                      reader.get_album_artist(tags).split(','))
-            if self.current_track.album_artist == '':
-                self.current_track.set_album_artists(
-                                                   self.current_track.artists)
             self.current_track.genres = reader.get_genres(tags).split(',')
             changed = True
         if changed:
@@ -576,11 +574,7 @@ class BinPlayer(BasePlayer):
         debug("Player::__on_bus_eos(): %s" % self.current_track.uri)
         if self._playbin.get_bus() == bus:
             self.stop()
-            self._finished = NextContext.NONE
-            if Lp().settings.get_value('repeat'):
-                self._context.next = NextContext.NONE
-            else:
-                self._context.next = NextContext.STOP_ALL
+            self._next_context = NextContext.NONE
             if self._next_track.id is not None:
                 self._load_track(self._next_track)
             self.emit('current-changed')
