@@ -38,7 +38,7 @@ class CommonPopover(Gtk.Popover):
             @param widget as Gtk.Widget
         """
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(False)
+        Lp().window.enable_global_shortcuts(False)
         size = Lp().window.get_size()
         self.set_size_request(size[0]*0.4,
                               size[1]*0.5)
@@ -49,7 +49,7 @@ class CommonPopover(Gtk.Popover):
             @param widget as Gtk.Widget
         """
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(True)
+        Lp().window.enable_global_shortcuts(True)
         self._widget.stop()
 
 
@@ -63,6 +63,8 @@ class CoversPopover(CommonPopover):
             Init Popover
             @param album as album
         """
+        if not album.artist_ids:
+            return
         CommonPopover.__init__(self)
         # FIXME We only search with first artist
         self._widget = ArtworkSearch(album.artist_ids[0],
