@@ -17,6 +17,7 @@ from threading import Thread
 
 from lollypop.define import Lp, OpenLink
 from lollypop.objects import Track
+from lollypop.utils import get_network_available
 from lollypop.widgets_info import WikipediaContent, LastfmContent
 from lollypop.cache import InfoCache
 from lollypop.view_artist_albums import CurrentArtistAlbumsView
@@ -83,7 +84,7 @@ class InfoPopover(Gtk.Popover):
         if Lp().lastfm is not None and\
                 not Lp().settings.get_value('use-librefm'):
             builder.get_object('scrolllastfm').show()
-        if InfoPopover.WebView is not None:
+        if InfoPopover.WebView is not None and get_network_available():
             builder.get_object('scrollduck').show()
         if not artist_ids:
             builder.get_object('scrolllyrics').show()
@@ -235,20 +236,32 @@ class InfoPopover(Gtk.Popover):
         if info is not None:
             tags = info.get_tags()
             lyrics = reader.get_lyrics(tags)
-        if lyrics or InfoPopover.WebView is None:
+        if lyrics or InfoPopover.WebView is None\
+                or not get_network_available():
             label = Gtk.Label()
             label.set_vexpand(True)
             label.set_hexpand(True)
             label.set_margin_top(10)
             label.set_margin_end(10)
+            label.get_style_context().add_class('dim-label')
             label.show()
             widget.add(label)
             if lyrics:
                 label.set_label(lyrics)
+            elif not get_network_available():
+                string = GLib.markup_escape_text(_("Network access disabled"))
+                label.set_markup(
+                       "<span font_weight='bold' size='xx-large'>" +
+                       string +
+                       "</span>")
             else:
-                label.set_label(
+                string = GLib.markup_escape_text(
                        _("No lyrics found, please install gir1.2-webkit2-4.0"))
-        else:
+                label.set_markup(
+                       "<span font_weight='bold' size='xx-large'>" +
+                       string +
+                       "</span>")
+        elif get_network_available():
             artists = ", ".join(Lp().player.current_track.artists)
             title = self.__current_track.name
             url = "http://genius.com/search?q=%s" % artists + " " + title
