@@ -12,7 +12,6 @@
 
 from gi.repository import Gio, GLib, Gtk
 
-from shutil import which
 from gettext import gettext as _
 from threading import Thread
 
@@ -346,18 +345,12 @@ class PopToolbarMenu(Gio.Menu):
             @param object id as int
         """
         Gio.Menu.__init__(self)
-        if not Lp().player.is_party:
+        if not Lp().player.is_party and (
+                Lp().player.get_albums() or
+                Lp().player.get_user_playlist()):
             builder = Gtk.Builder()
             builder.add_from_resource('/org/gnome/Lollypop/PlaybackMenu.ui')
             playback_menu = builder.get_object('playback-menu')
-            playback_action = Gio.SimpleAction.new_stateful(
-                            'playback',
-                            GLib.VariantType.new("s"),
-                            GLib.Variant("s", str(Lp().player.context.next)))
-            playback_action.connect('change-state', self.__on_change_state)
-            Lp().add_action(playback_action)
-            if Lp().player.get_user_playlist_ids():
-                playback_menu.remove(2)
             self.insert_section(0, _("Playback"),
                                 playback_menu)
         self.insert_section(1, _("Playlists"),
@@ -366,14 +359,6 @@ class PopToolbarMenu(Gio.Menu):
 #######################
 # PRIVATE             #
 #######################
-    def __on_change_state(self, action, value):
-        """
-            Update playback value
-            @param action as Gio.SimpleAction
-            @param param as GLib.Variant
-        """
-        action.set_state(value)
-        Lp().player.set_next_context(int(value.get_string()))
 
 
 class EditMenu(BaseMenu):
@@ -396,7 +381,7 @@ class EditMenu(BaseMenu):
         elif is_album:
             favorite = Lp().settings.get_value('tag-editor').get_string()
             for editor in [favorite] + self.__TAG_EDITORS:
-                if which(editor) is not None:
+                if GLib.find_program_in_path(editor) is not None:
                     self.__tag_editor = editor
                     self.__set_edit_actions()
                     break
@@ -436,6 +421,8 @@ class EditMenu(BaseMenu):
             album = Album(self._object_id)
             for track_id in album.track_ids:
                 artist_ids += Lp().tracks.get_artist_ids(track_id)
+                uri = Lp().tracks.get_uri(track_id)
+                Lp().playlists.remove(uri)
                 Lp().tracks.remove(track_id)
                 Lp().tracks.clean(track_id)
                 art_file = Lp().art.get_album_cache_name(album)
@@ -444,6 +431,8 @@ class EditMenu(BaseMenu):
             track = Track(self._object_id)
             album = track.album
             artist_ids = Lp().tracks.get_artist_ids(track.id)
+            uri = Lp().tracks.get_uri(track.id)
+            Lp().playlists.remove(uri)
             Lp().tracks.remove(track.id)
             Lp().tracks.clean(track.id)
         artist_ids += album.artist_ids
@@ -468,12 +457,16 @@ class EditMenu(BaseMenu):
             @param SimpleAction
             @param GVariant
         """
-        album_path = Lp().albums.get_path(self._object_id)
-        argv = [self.__tag_editor, album_path, None]
-        GLib.spawn_async_with_pipes(
-                                None, argv, None,
-                                GLib.SpawnFlags.SEARCH_PATH |
-                                GLib.SpawnFlags.DO_NOT_REAP_CHILD, None)
+        try:
+            album_uri = Lp().albums.get_uri(self._object_id)
+            argv = [self.__tag_editor,
+                    GLib.filename_from_uri(album_uri)[0], None]
+            GLib.spawn_async_with_pipes(
+                                    None, argv, None,
+                                    GLib.SpawnFlags.SEARCH_PATH |
+                                    GLib.SpawnFlags.DO_NOT_REAP_CHILD, None)
+        except:
+            pass
 
 
 class AlbumMenu(Gio.Menu):
