@@ -13,15 +13,13 @@
 from gi.repository import Gtk, GLib, Gio, Gdk, GdkPixbuf
 
 from gettext import gettext as _
-from cgi import escape
 from threading import Thread
-from shutil import which
 
 from lollypop.define import Lp, ArtSize, Type, DbPersistent
 from lollypop.objects import Track, Album
 from lollypop.pop_menu import TrackMenuPopover, TrackMenu
 from lollypop.pop_album import AlbumPopover
-from lollypop.utils import noaccents
+from lollypop.utils import noaccents, get_network_available
 
 
 class SearchRow(Gtk.ListBoxRow):
@@ -241,8 +239,8 @@ class SearchRow(Gtk.ListBoxRow):
         layout_title = self.__name.get_layout()
         layout_artist = self.__artist.get_layout()
         if layout_title.is_ellipsized() or layout_artist.is_ellipsized():
-            artist = escape(self.__artist.get_text())
-            title = escape(self.__name.get_text())
+            artist = GLib.markup_escape_text(self.__artist.get_text())
+            title = GLib.markup_escape_text(self.__name.get_text())
             self.set_tooltip_markup("<b>%s</b>\n%s" % (artist, title))
         else:
             self.set_tooltip_text('')
@@ -284,12 +282,11 @@ class SearchPopover(Gtk.Popover):
         self.__spinner = builder.get_object('spinner')
         self.__stack = builder.get_object('stack')
 
-        switch = builder.get_object('search-switch')
-        if which("youtube-dl") is None:
-            switch.set_sensitive(False)
-            switch.set_tooltip_text(_("You need to install youtube-dl"))
+        self.__switch = builder.get_object('search-switch')
+        if GLib.find_program_in_path("youtube-dl") is None:
+            self.__switch.set_tooltip_text(_("You need to install youtube-dl"))
         else:
-            switch.set_state(Lp().settings.get_value('network-search'))
+            self.__switch.set_state(Lp().settings.get_value('network-search'))
         builder.get_object('scrolled').add(self.__view)
         self.add(builder.get_object('widget'))
         # Connect here because we don't want previous switch.set_state()
@@ -341,18 +338,19 @@ class SearchPopover(Gtk.Popover):
             @param state as bool
         """
         Lp().settings.set_boolean('network-search', state)
-        Lp().window.reload_view()
-        if state:
-            if Lp().charts is None:
-                from lollypop.charts import Charts
-                Lp().charts = Charts()
-            Lp().charts.update()
-        else:
-            Lp().charts.stop()
+        GLib.idle_add(self._on_search_changed, self.__entry)
 
 #######################
 # PRIVATE             #
 #######################
+    def __enable_network_search(self):
+        """
+            True if shoud enable network search
+            @return bool
+        """
+        return GLib.find_program_in_path("youtube-dl") is not None and\
+            get_network_available()
+
     def __calculate_score(self, row):
         """
             Calculate score for row
@@ -528,7 +526,7 @@ class SearchPopover(Gtk.Popover):
             @return True
         """
         return Lp().settings.get_value('network-search') and\
-            which("youtube-dl") is not None
+            GLib.find_program_in_path("youtube-dl") is not None
 
     def __on_local_item_found(self, search):
         """
@@ -582,8 +580,9 @@ class SearchPopover(Gtk.Popover):
             Disable global shortcuts and resize
             @param widget as Gtk.Widget
         """
+        self.__switch.set_sensitive(self.__enable_network_search())
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(False)
+        Lp().window.enable_global_shortcuts(False)
         height = Lp().window.get_size()[1]
         self.set_size_request(400, height*0.7)
 
@@ -593,7 +592,7 @@ class SearchPopover(Gtk.Popover):
             @param widget as Gtk.Widget
         """
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(True)
+        Lp().window.enable_global_shortcuts(True)
         self.__reset_search()
         self.__stack.set_visible_child(self.__new_btn)
         self.__spinner.stop()
