@@ -12,12 +12,12 @@
 
 from gi.repository import Gtk, Gdk, GLib, GObject, Pango
 
-from cgi import escape
 from gettext import gettext as _
 from locale import strcoll
 
 from lollypop.cellrenderer import CellRendererArtist
 from lollypop.define import Type, Lp, ArtSize
+from lollypop.utils import get_network_available
 
 
 class SelectionPopover(Gtk.Popover):
@@ -308,7 +308,8 @@ class SelectionList(Gtk.Bin):
         items.append((Type.RANDOMS, _("Random albums")))
         items.append((Type.PLAYLISTS, _("Playlists")))
         items.append((Type.RADIOS, _("Radios")))
-        if Lp().settings.get_value('network-search'):
+        if Lp().settings.get_value('show-charts') and\
+                get_network_available():
             items.append((Type.CHARTS, _("The charts")))
         if self.__is_artists:
             items.append((Type.ALL, _("All albums")))
@@ -363,7 +364,7 @@ class SelectionList(Gtk.Bin):
                 layout.set_width(Pango.units_from_double(width))
                 layout.set_text(text, -1)
                 if layout.is_ellipsized():
-                    tooltip.set_markup(escape(text))
+                    tooltip.set_markup(GLib.markup_escape_text(text))
                     return True
         return False
 
@@ -520,7 +521,7 @@ class SelectionList(Gtk.Bin):
             @param event as Gdk.Event
         """
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(False)
+        Lp().window.enable_global_shortcuts(False)
 
     def __on_leave_notify(self, widget, event):
         """
@@ -529,7 +530,7 @@ class SelectionList(Gtk.Bin):
             @param event as GdK.Event
         """
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(True)
+        Lp().window.enable_global_shortcuts(True)
         self.__hide_popover()
         self.__last_motion_event = None
 
