@@ -20,13 +20,14 @@ except:
 from gettext import gettext as _
 from gettext import ngettext as ngettext
 from threading import Thread
-from shutil import which
 from re import findall, DOTALL
 
-from lollypop.define import Lp, SecretSchema, SecretAttributes
+from lollypop.define import Lp, SecretSchema, SecretAttributes, Type
 from lollypop.cache import InfoCache
 from lollypop.database import Database
+from lollypop.touch_helper import TouchHelper
 from lollypop.database_history import History
+from lollypop.utils import get_network_available
 
 
 class Settings(Gio.Settings):
@@ -48,20 +49,21 @@ class Settings(Gio.Settings):
         settings.__class__ = Settings
         return settings
 
-    def get_music_paths(self):
+    def get_music_uris(self):
         """
-            Return music paths
+            Return music uris
             @return [str]
         """
-        paths = self.get_value('music-path')
-        if not paths:
-            if GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_MUSIC):
-                paths = [GLib.get_user_special_dir(
-                    GLib.UserDirectory.DIRECTORY_MUSIC)]
+        uris = self.get_value('music-uris')
+        if not uris:
+            filename = GLib.get_user_special_dir(
+                                            GLib.UserDirectory.DIRECTORY_MUSIC)
+            if filename:
+                uris = [GLib.filename_to_uri(filename)]
             else:
-                print("You need to add a music path"
+                print("You need to add a music uri"
                       " to org.gnome.Lollypop in dconf")
-        return paths
+        return list(uris)
 
 
 class SettingsDialog:
@@ -126,6 +128,9 @@ class SettingsDialog:
 
         switch_mix = builder.get_object('switch_mix')
         switch_mix.set_state(Lp().settings.get_value('mix'))
+        helper = TouchHelper(switch_mix, None, None)
+        helper.set_long_func(self.__mix_long_func, switch_mix)
+        helper.set_short_func(self.__mix_short_func, switch_mix)
 
         switch_mix_party = builder.get_object('switch_mix_party')
         switch_mix_party.set_state(Lp().settings.get_value('party-mix'))
@@ -134,7 +139,7 @@ class SettingsDialog:
         switch_librefm.set_state(Lp().settings.get_value('use-librefm'))
 
         switch_artwork_tags = builder.get_object('switch_artwork_tags')
-        if which("kid3-cli") is None:
+        if GLib.find_program_in_path("kid3-cli") is None:
             grid = builder.get_object('grid_behaviour')
             h = grid.child_get_property(switch_artwork_tags, 'height')
             w = grid.child_get_property(switch_artwork_tags, 'width')
@@ -150,6 +155,12 @@ class SettingsDialog:
             switch_artwork_tags.set_state(
                                       Lp().settings.get_value('save-to-tags'))
 
+        if GLib.find_program_in_path("youtube-dl") is None:
+            builder.get_object('charts_grid').hide()
+        else:
+            switch_charts = builder.get_object('switch_charts')
+            switch_charts.set_state(Lp().settings.get_value('show-charts'))
+
         switch_genres = builder.get_object('switch_genres')
         switch_genres.set_state(Lp().settings.get_value('show-genres'))
 
@@ -160,9 +171,6 @@ class SettingsDialog:
         switch_artwork = builder.get_object('switch_artwork')
         switch_artwork.set_state(Lp().settings.get_value('artist-artwork'))
 
-        switch_repeat = builder.get_object('switch_repeat')
-        switch_repeat.set_state(not Lp().settings.get_value('repeat'))
-
         combo_orderby = builder.get_object('combo_orderby')
         combo_orderby.set_active(Lp().settings.get_enum(('orderby')))
 
@@ -185,7 +193,7 @@ class SettingsDialog:
         # Music tab
         #
         dirs = []
-        for directory in Lp().settings.get_value('music-path'):
+        for directory in Lp().settings.get_value('music-uris'):
             dirs.append(directory)
 
         # Main chooser
@@ -196,11 +204,16 @@ class SettingsDialog:
         self.__main_chooser.set_action(self.__add_chooser)
         main_chooser_box.pack_start(self.__main_chooser, False, True, 0)
         if len(dirs) > 0:
-            path = dirs.pop(0)
+            uri = dirs.pop(0)
         else:
-            path = GLib.get_user_special_dir(
-                GLib.UserDirectory.DIRECTORY_MUSIC)
-        self.__main_chooser.set_dir(path)
+            filename = GLib.get_user_special_dir(
+                                            GLib.UserDirectory.DIRECTORY_MUSIC)
+            if filename:
+                uri = GLib.filename_to_uri(filename)
+            else:
+                uri = ""
+
+        self.__main_chooser.set_dir(uri)
 
         # Others choosers
         for directory in dirs:
@@ -297,6 +310,32 @@ class SettingsDialog:
         Lp().settings.set_value('show-genres',
                                 GLib.Variant('b', state))
 
+    def _update_charts_setting(self, widget, state):
+        """
+            Update show charts setting
+            @param widget as Gtk.Switch
+            @param state as bool
+        """
+        if Lp().settings.get_value('network-access'):
+            GLib.idle_add(Lp().window.add_remove_from,
+                          (Type.CHARTS, _("The charts")),
+                          True,
+                          state)
+        if state:
+            if Lp().charts is None:
+                from lollypop.charts import Charts
+                Lp().charts = Charts()
+            if get_network_available():
+                Lp().charts.update()
+            elif Lp().notify is not None:
+                Lp().notify.send(_("The charts"),
+                                 _("Network access disabled"))
+        else:
+            Lp().charts.stop()
+            Lp().scanner.clean_charts()
+        Lp().settings.set_value('show-charts',
+                                GLib.Variant('b', state))
+
     def _update_mix_setting(self, widget, state):
         """
             Update mix setting
@@ -369,15 +408,6 @@ class SettingsDialog:
         if state:
             Lp().art.cache_artists_info()
 
-    def _update_repeat_setting(self, widget, state):
-        """
-            Update repeat setting
-            @param widget as Gtk.Switch
-            @param state as bool
-        """
-        Lp().settings.set_value('repeat',
-                                GLib.Variant('b', not state))
-
     def _update_orderby_setting(self, widget):
         """
             Update orderby setting
@@ -440,26 +470,6 @@ class SettingsDialog:
         """
         combo.set_tooltip_text(combo.get_active_text())
 
-    def _on_mix_button_press(self, widget, event):
-        """
-            Show mix popover on long press
-            @param widget as Gtk.Widget
-            @param event as Gdk.Event
-        """
-        self.__mix_tid = GLib.timeout_add(500, self.__show_mix_popover, widget)
-
-    def _on_mix_button_release(self, widget, event):
-        """
-            If no popover shown, pass event
-            @param widget as Gtk.Widget
-            @param event as Gdk.Event
-        """
-        if self.__mix_tid is None:
-            return True
-        else:
-            GLib.source_remove(self.__mix_tid)
-            self.__mix_tid = None
-
     def _on_key_release_event(self, widget, event):
         """
             Destroy window if Esc
@@ -475,7 +485,7 @@ class SettingsDialog:
             @param button as Gtk.Button
         """
         self._update_lastfm_settings(True)
-        if not Gio.NetworkMonitor.get_default().get_network_available():
+        if not get_network_available():
             self.__test_img.set_from_icon_name('computer-fail-symbolic',
                                                Gtk.IconSize.MENU)
             return
@@ -493,6 +503,26 @@ class SettingsDialog:
 #######################
 # PRIVATE             #
 #######################
+    def __mix_long_func(self, args):
+        """
+            Show popover
+            @param args as []
+        """
+        if Lp().settings.get_value('mix'):
+            if self.__popover is None:
+                self.__popover = Gtk.Popover.new(args[0])
+                self.__popover.set_modal(False)
+                self.__popover.add(self.__popover_content)
+            self.__popover.show_all()
+
+    def __mix_short_func(self, args):
+        """
+            Activate switch
+            @param args as []
+        """
+        args[0].set_active(not args[0].get_active())
+        return True
+
     def __get_pa_outputs(self):
         """
             Get PulseAudio outputs
@@ -534,7 +564,7 @@ class SettingsDialog:
     def __add_chooser(self, directory=None):
         """
             Add a new chooser widget
-            @param directory path as string
+            @param directory uri as string
         """
         chooser = ChooserWidget()
         image = Gtk.Image.new_from_icon_name("list-remove-symbolic",
@@ -565,23 +595,21 @@ class SettingsDialog:
             Close edit party dialog
             @param widget as Gtk.Window
         """
-        # Music path
-        paths = []
-        main_path = self.__main_chooser.get_dir()
+        # Music uris
+        uris = []
+        default = GLib.get_user_special_dir(
+                                            GLib.UserDirectory.DIRECTORY_MUSIC)
+        main_uri = self.__main_chooser.get_dir()
         choosers = self.__chooser_box.get_children()
-        if main_path == GLib.get_user_special_dir(
-            GLib.UserDirectory.DIRECTORY_MUSIC)\
-           and not choosers:
-            paths = []
-        else:
-            paths.append(main_path)
+        if main_uri != GLib.filename_to_uri(default) or choosers:
+            uris.append(main_uri)
             for chooser in choosers:
-                path = chooser.get_dir()
-                if path is not None and path not in paths:
-                    paths.append(path)
+                uri = chooser.get_dir()
+                if uri is not None and uri not in uris:
+                    uris.append(uri)
 
-        previous = Lp().settings.get_value('music-path')
-        Lp().settings.set_value('music-path', GLib.Variant('as', paths))
+        previous = Lp().settings.get_value('music-uris')
+        Lp().settings.set_value('music-uris', GLib.Variant('as', uris))
 
         # Last.fm
         try:
@@ -592,22 +620,10 @@ class SettingsDialog:
 
         self.__settings_dialog.hide()
         self.__settings_dialog.destroy()
-        if set(previous) != set(paths):
+        if set(previous) != set(uris):
             Lp().window.update_db()
-        Lp().window.update_view()
-
-    def __show_mix_popover(self, widget):
-        """
-            Show mix popover
-            @param widget as Gtk.Widget
-        """
-        self.__mix_tid = None
-        if Lp().settings.get_value('mix'):
-            if self.__popover is None:
-                self.__popover = Gtk.Popover.new(widget)
-                self.__popover.set_modal(False)
-                self.__popover.add(self.__popover_content)
-            self.__popover.show_all()
+        if Lp().window.view is not None:
+            Lp().window.view.update_children()
 
     def __test_lastfm_connection(self):
         """
@@ -649,8 +665,8 @@ class SettingsDialog:
         if track_ids:
             track_id = track_ids.pop(0)
             uri = Lp().tracks.get_uri(track_id)
-            filepath = GLib.filename_from_uri(uri)[0]
-            name = GLib.path_get_basename(filepath)
+            f = Gio.File.new_for_uri(uri)
+            name = f.get_basename()
             album_id = Lp().tracks.get_album_id(track_id)
             popularity = Lp().tracks.get_popularity(track_id)
             ltime = Lp().tracks.get_ltime(track_id)
@@ -708,6 +724,7 @@ class ChooserWidget(Gtk.Grid):
         self.set_property("orientation", Gtk.Orientation.HORIZONTAL)
         self.set_property("halign", Gtk.Align.CENTER)
         self.__chooser_btn = Gtk.FileChooserButton()
+        self.__chooser_btn.set_local_only(False)
         self.__chooser_btn.set_action(Gtk.FileChooserAction.SELECT_FOLDER)
         self.__chooser_btn.set_property("margin", 5)
         self.__chooser_btn.show()
@@ -719,13 +736,13 @@ class ChooserWidget(Gtk.Grid):
         self.__action_btn.connect("clicked", self.___do_action)
         self.show()
 
-    def set_dir(self, path):
+    def set_dir(self, uri):
         """
-            Set current selected path for chooser
-            @param directory path as string
+            Set current selected uri for chooser
+            @param directory uri as string
         """
-        if path:
-            self.__chooser_btn.set_uri("file://"+path)
+        if uri:
+            self.__chooser_btn.set_uri(uri)
 
     def set_icon(self, image):
         """
@@ -743,17 +760,10 @@ class ChooserWidget(Gtk.Grid):
 
     def get_dir(self):
         """
-            Return select directory path
-            @return path as string
+            Return select directory uri
+            @return uri as string
         """
-        path = None
-        uri = self.__chooser_btn.get_uri()
-        if uri is not None:
-            path = GLib.uri_unescape_string(uri, None)
-        if path is not None:
-            return path[7:]
-        else:
-            return None
+        return self.__chooser_btn.get_uri()
 
 #######################
 # PRIVATE             #
