@@ -11,9 +11,9 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from gi.repository import Gtk, Gdk, GLib
-from cgi import escape
 
 from lollypop.controllers import InfosController
+from lollypop.touch_helper import TouchHelper
 from lollypop.define import Lp, Type, ArtSize
 
 
@@ -39,6 +39,10 @@ class ToolbarInfo(Gtk.Bin, InfosController):
         self._infobox = builder.get_object('info')
         self.add(self._infobox)
 
+        helper = TouchHelper(self._infobox, None, None)
+        helper.set_long_func(self.__on_info_long)
+        helper.set_short_func(self.__on_info_short)
+
         self._spinner = builder.get_object('spinner')
 
         self.__labels = builder.get_object('nowplaying_labels')
@@ -85,51 +89,6 @@ class ToolbarInfo(Gtk.Bin, InfosController):
 #######################
 # PROTECTED           #
 #######################
-    def _on_title_press_event(self, widget, event):
-        """
-            On long press: show current track menu
-            @param widget as Gtk.Widget
-            @param event as Gdk.Event
-
-        """
-        self.__timeout_id = GLib.timeout_add(500, self.__show_track_menu)
-        return True
-
-    def _on_title_release_event(self, widget, event):
-        """
-            Show track information popover
-            On long press/right click: show current track menu
-            @param widget as Gtk.Widget
-            @param event as Gdk.Event
-        """
-        if self.__timeout_id is not None:
-            GLib.source_remove(self.__timeout_id)
-            self.__timeout_id = None
-            if Lp().player.current_track.id == Type.EXTERNALS:
-                from lollypop.pop_externals import ExternalsPopover
-                expopover = ExternalsPopover()
-                expopover.set_relative_to(widget)
-                expopover.populate()
-                expopover.show()
-            elif Lp().player.current_track.id is not None:
-                if event.button == 1:
-                    if Lp().player.current_track.id == Type.RADIOS:
-                        if self.__pop_tunein is None:
-                            from lollypop.pop_tunein import TuneinPopover
-                            self.__pop_tunein = TuneinPopover()
-                            self.__pop_tunein.populate()
-                            self.__pop_tunein.set_relative_to(widget)
-                        self.__pop_tunein.show()
-                    else:
-                        if self.__pop_info is None:
-                            from lollypop.pop_info import InfoPopover
-                            self.__pop_info = InfoPopover()
-                            self.__pop_info.set_relative_to(widget)
-                        self.__pop_info.show()
-                else:
-                    self.__show_track_menu()
-        return True
-
     def _on_eventbox_realize(self, eventbox):
         """
             Show hand cursor over
@@ -164,11 +123,11 @@ class ToolbarInfo(Gtk.Bin, InfosController):
             self._cover.set_from_surface(pixbuf)
             del pixbuf
 
-    def __show_track_menu(self):
+    def __on_info_long(self, args):
         """
             Show current track menu
+            @param args as []
         """
-        self.__timeout_id = None
         if Lp().player.current_track.id >= 0:
             from lollypop.pop_menu import PopToolbarMenu
             from lollypop.pop_menu import TrackMenuPopover
@@ -178,6 +137,32 @@ class ToolbarInfo(Gtk.Bin, InfosController):
             popover.set_relative_to(self._infobox)
             popover.show()
 
+    def __on_info_short(self, args):
+        """
+            Show track information popover
+            @param args as []
+        """
+        if Lp().player.current_track.id == Type.EXTERNALS:
+            from lollypop.pop_externals import ExternalsPopover
+            expopover = ExternalsPopover()
+            expopover.set_relative_to(self._infobox)
+            expopover.populate()
+            expopover.show()
+        elif Lp().player.current_track.id is not None:
+            if Lp().player.current_track.id == Type.RADIOS:
+                if self.__pop_tunein is None:
+                    from lollypop.pop_tunein import TuneinPopover
+                    self.__pop_tunein = TuneinPopover()
+                    self.__pop_tunein.populate()
+                    self.__pop_tunein.set_relative_to(self._infobox)
+                self.__pop_tunein.show()
+            else:
+                if self.__pop_info is None:
+                    from lollypop.pop_info import InfoPopover
+                    self.__pop_info = InfoPopover()
+                    self.__pop_info.set_relative_to(self._infobox)
+                self.__pop_info.show()
+
     def __on_loading_changed(self, player, show):
         """
             Show spinner based on loading status
@@ -222,8 +207,8 @@ class ToolbarInfo(Gtk.Bin, InfosController):
         layout_title = self._title_label.get_layout()
         layout_artist = self._artist_label.get_layout()
         if layout_title.is_ellipsized() or layout_artist.is_ellipsized():
-            artist = escape(self._artist_label.get_text())
-            title = escape(self._title_label.get_text())
+            artist = GLib.markup_escape_text(self._artist_label.get_text())
+            title = GLib.markup_escape_text(self._title_label.get_text())
             tooltip.set_markup("<b>%s</b> - %s" % (artist, title))
         else:
             return False
