@@ -20,12 +20,14 @@ class View(Gtk.Grid):
         Generic view
     """
 
-    def __init__(self):
+    def __init__(self, filtered=False):
         """
             Init view
+            @param filtered as bool
         """
         Gtk.Grid.__init__(self)
         self.connect('destroy', self._on_destroy)
+        self.__overlayed = None
         self.set_property('orientation', Gtk.Orientation.VERTICAL)
         self.set_border_width(0)
         self.__current_signal = Lp().player.connect('current-changed',
@@ -39,6 +41,31 @@ class View(Gtk.Grid):
         self._stop = False
         self.__new_ids = []
 
+        if filtered:
+            self._filter = ""
+            grid = Gtk.Grid()
+            grid.set_column_spacing(2)
+            self.__search_entry = Gtk.SearchEntry.new()
+            self.__search_entry.connect('search-changed',
+                                        self._on_search_changed)
+            self.__search_entry.connect('key-press-event',
+                                        self.__on_key_press)
+            self.__search_entry.set_size_request(400, -1)
+            self.__search_entry.show()
+            button = Gtk.Button.new_from_icon_name('window-close-symbolic',
+                                                   Gtk.IconSize.MENU)
+            button.set_relief(Gtk.ReliefStyle.NONE)
+            button.connect('clicked', self.__on_button_clicked)
+            button.show()
+            grid.add(self.__search_entry)
+            grid.add(button)
+            grid.show()
+            self.__search_bar = Gtk.SearchBar.new()
+            self.__search_bar.add(grid)
+            self.add(self.__search_bar)
+        else:
+            self._filter = None
+
         self._scrolled = Gtk.ScrolledWindow()
         self._scrolled.connect('leave-notify-event', self.__on_leave_notify)
         self._scrolled.show()
@@ -54,17 +81,38 @@ class View(Gtk.Grid):
         for child in self._get_children():
             child.stop()
 
+    def disable_overlay(self):
+        """
+            Disable overlay widget
+        """
+        if self.__overlayed is not None:
+            self.__overlayed.show_overlay(False)
+
     def update_children(self):
         """
             Update children
         """
         GLib.idle_add(self.__update_widgets, self._get_children())
 
-    def disable_overlays(self):
+    def set_search_mode(self):
         """
-            Disable children's overlay
+           Set search mode
         """
-        GLib.idle_add(self._disable_overlays, self._get_children())
+        if self._filter is not None:
+            enable = not self.__search_bar.get_search_mode()
+            Lp().window.enable_global_shortcuts(not enable)
+            self.__search_bar.show() if enable else self.__search_bar.hide()
+            self.__search_bar.set_search_mode(enable)
+            if enable:
+                self.__search_entry.grab_focus()
+
+    @property
+    def filtered(self):
+        """
+            True if view filtered
+            @return bool
+        """
+        return self._filter is not None and self._filter != ""
 
     def populate(self):
         pass
@@ -72,15 +120,19 @@ class View(Gtk.Grid):
 #######################
 # PROTECTED           #
 #######################
-    def _disable_overlays(self, widgets):
+    def _filter_func(self, child):
         """
-            Disable children's overlay
-            @param widgets as AlbumWidget
+            Filter function for a Gtk.FlowBox/GtkListBox
+            @param child as Gtk.FlowBoxChild/Gtk.ListBoxChild
         """
-        if widgets:
-            widget = widgets.pop(0)
-            widget.show_overlay(False)
-            GLib.idle_add(self._disable_overlays, widgets)
+        if not self.filtered:
+            return True
+        filter = self._filter.lower()
+        if child.filter.lower().find(filter) != -1:
+            child.set_filtered(False)
+            return True
+        child.set_filtered(True)
+        return False
 
     def _get_children(self):
         """
@@ -88,6 +140,19 @@ class View(Gtk.Grid):
         """
         return []
 
+    def _on_overlayed(self, widget, value):
+        """
+            Keep overlayed widget, clean previously overlayed
+            @param widget as AlbumWidget
+            @param value as bool
+        """
+        if value:
+            if self.__overlayed is not None:
+                self.__overlayed.show_overlay(False)
+            self.__overlayed = widget
+        elif self.__overlayed == widget:
+            self.__overlayed = None
+
     def _on_current_changed(self, player):
         """
             Current song changed
@@ -103,6 +168,14 @@ class View(Gtk.Grid):
         """
         GLib.idle_add(self.__update_duration, self._get_children(), track_id)
 
+    def _on_search_changed(self, entry):
+        """
+            Update filter
+            @param entry as Gtk.Entry
+        """
+        self._filter = self.__search_entry.get_text()
+        self._box.invalidate_filter()
+
     def _on_destroy(self, widget):
         """
             Remove signals on unamp
@@ -141,6 +214,29 @@ class View(Gtk.Grid):
             widget.update_duration(track_id)
             GLib.idle_add(self.__update_duration, widgets, track_id)
 
+    def __on_button_clicked(self, widget):
+        """
+            Hide widget, why GTK doesn't do that?
+            Otherwise, we get an ugly frame
+            @param widget as Gtk.Button
+        """
+        self.__search_entry.set_text("")
+        self.__search_bar.set_search_mode(False)
+        self.__search_bar.hide()
+
+    def __on_key_press(self, widget, event):
+        """
+            If Esc, hide widget, why GTK doesn't do that?
+            Otherwise, we get an ugly frame
+            @param widget as Gtk.SearchEntry
+            @param event as Gdk.Event
+        """
+        if event.keyval == 65307:
+            self.__search_entry.set_text("")
+            self.__search_bar.set_search_mode(False)
+            self.__search_bar.hide()
+            return True
+
     def __on_leave_notify(self, widget, event):
         """
             Update overlays as internal widget may not have received the signal
@@ -152,7 +248,7 @@ class View(Gtk.Grid):
            event.x >= allocation.width or\
            event.y <= 0 or\
            event.y >= allocation.height:
-            self.disable_overlays()
+            self.disable_overlay()
 
     def __on_cover_changed(self, art, album_id):
         """
@@ -170,11 +266,12 @@ class LazyLoadingView(View):
         Lazy loading for view
     """
 
-    def __init__(self):
+    def __init__(self, filtered=False):
         """
             Init lazy loading
+            @param filtered as bool
         """
-        View.__init__(self)
+        View.__init__(self, filtered)
         self._lazy_queue = []  # Widgets not initialized
         self._scroll_value = 0
         self.__prev_scroll_value = 0
