@@ -12,7 +12,7 @@
 
 from gi.repository import Gtk, GLib, Gdk
 
-from lollypop.view import View, LazyLoadingView
+from lollypop.view import LazyLoadingView
 from lollypop.widgets_album import AlbumSimpleWidget
 from lollypop.pop_album import AlbumPopover
 from lollypop.pop_menu import AlbumMenu, AlbumMenuPopover
@@ -31,25 +31,27 @@ class AlbumsView(LazyLoadingView):
             @param genre ids as [int]
             @param artist ids as [int]
         """
-        LazyLoadingView.__init__(self)
+        LazyLoadingView.__init__(self, True)
         self.__signal = None
         self.__context_album_id = None
         self.__genre_ids = genre_ids
         self.__artist_ids = artist_ids
         self.__press_rect = None
 
-        self.__albumbox = Gtk.FlowBox()
-        self.__albumbox.set_selection_mode(Gtk.SelectionMode.NONE)
-        self.__albumbox.connect('child-activated', self.__on_album_activated)
-        self.__albumbox.connect('button-press-event', self.__on_button_press)
+        self._box = Gtk.FlowBox()
+        self._box.set_filter_func(self._filter_func)
+        self._box.set_selection_mode(Gtk.SelectionMode.NONE)
+        self._box.connect('child-activated', self.__on_album_activated)
+        self._box.connect('button-press-event', self.__on_button_press)
         # Allow lazy loading to not jump up and down
-        self.__albumbox.set_homogeneous(True)
-        self.__albumbox.set_max_children_per_line(1000)
-        self.__albumbox.show()
+        self._box.set_homogeneous(True)
+        self._box.set_max_children_per_line(1000)
+        self._box.show()
 
         self._viewport.set_property('valign', Gtk.Align.START)
         self._viewport.set_property('margin', 5)
         self._scrolled.set_property('expand', True)
+
         self.add(self._scrolled)
 
     def populate(self, albums):
@@ -62,20 +64,13 @@ class AlbumsView(LazyLoadingView):
 #######################
 # PROTECTED           #
 #######################
-    def _disable_overlays(self, widgets):
-        """
-            Disable children's overlay
-            @param widgets as AlbumWidget
-        """
-        View._disable_overlays(self, widgets)
-
     def _get_children(self):
         """
             Return view children
             @return [AlbumWidget]
         """
         children = []
-        for child in self.__albumbox.get_children():
+        for child in self._box.get_children():
             children.append(child)
         return children
 
@@ -95,14 +90,15 @@ class AlbumsView(LazyLoadingView):
             widget = AlbumSimpleWidget(albums.pop(0),
                                        self.__genre_ids,
                                        self.__artist_ids)
-            self.__albumbox.insert(widget, -1)
+            widget.connect('overlayed', self._on_overlayed)
+            self._box.insert(widget, -1)
             widget.show()
             self._lazy_queue.append(widget)
             GLib.idle_add(self.__add_albums, albums)
         else:
             GLib.idle_add(self.lazy_loading)
             if self._viewport.get_child() is None:
-                self._viewport.add(self.__albumbox)
+                self._viewport.add(self._box)
 
     def __on_album_activated(self, flowbox, album_widget):
         """
@@ -117,7 +113,7 @@ class AlbumsView(LazyLoadingView):
         # FIXME: Report a bug and check always true
         (x, y) = album_widget.translate_coordinates(self._scrolled, 0, 0)
         if y < 0:
-            y = album_widget.translate_coordinates(self.__albumbox, 0, 0)[1]
+            y = album_widget.translate_coordinates(self._box, 0, 0)[1]
             self._scrolled.get_allocation().height + y
             self._scrolled.get_vadjustment().set_value(y)
         if self.__press_rect is not None:
