@@ -12,6 +12,8 @@
 
 from gi.repository import Gtk, GLib, GObject
 
+from gettext import gettext as _
+
 from lollypop.view import LazyLoadingView, View
 from lollypop.view_container import ViewContainer
 from lollypop.define import Lp, Type, ArtSize
@@ -34,7 +36,7 @@ class ArtistAlbumsView(LazyLoadingView):
             @param genre ids as [int]
             @param show cover as bool
         """
-        LazyLoadingView.__init__(self)
+        LazyLoadingView.__init__(self, True)
         self._artist_ids = artist_ids
         self._genre_ids = genre_ids
         self.__show_cover = show_cover
@@ -70,6 +72,18 @@ class ArtistAlbumsView(LazyLoadingView):
             if len(albums) != 1:
                 self.__spinner.start()
             self.__add_albums(albums)
+        else:
+            label = Gtk.Label.new()
+            string = GLib.markup_escape_text(_("Network access disabled"))
+            label.set_markup(
+                       "<span font_weight='bold' size='xx-large'>" +
+                       string +
+                       "</span>")
+            label.set_property('halign', Gtk.Align.CENTER)
+            label.set_hexpand(True)
+            label.show()
+            self.set_sensitive(False)
+            self._albumbox.add(label)
 
     def jump_to_current(self):
         """
@@ -98,6 +112,16 @@ class ArtistAlbumsView(LazyLoadingView):
 #######################
 # PROTECTED           #
 #######################
+    def _on_search_changed(self, entry):
+        """
+            Update filter
+            @param entry as Gtk.Entry
+        """
+        self._filter = entry.get_text()
+        for child in self._get_children():
+            for box in child.boxes:
+                box.invalidate_filter()
+
     def _get_children(self):
         """
             Return view children
@@ -145,6 +169,8 @@ class ArtistAlbumsView(LazyLoadingView):
                                          self._genre_ids,
                                          self._artist_ids,
                                          self.__show_cover)
+            widget.set_filter_func(self._filter_func)
+            widget.connect('overlayed', self._on_overlayed)
             self._lazy_queue.append(widget)
             widget.show()
             self._albumbox.add(widget)
