@@ -12,8 +12,6 @@
 
 from gi.repository import Gtk, GLib
 
-from cgi import escape
-
 from lollypop.view import View
 from lollypop.widgets_playlist import PlaylistsWidget, PlaylistEditWidget
 from lollypop.widgets_playlist import PlaylistsManagerWidget
@@ -32,7 +30,7 @@ class PlaylistsView(View):
             @parma playlist ids as [int]
             @param editable as bool
         """
-        View.__init__(self)
+        View.__init__(self, True)
         self.__tracks = []
         self.__playlist_ids = playlist_ids
         self.__signal_id1 = Lp().playlists.connect('playlist-add',
@@ -60,6 +58,7 @@ class PlaylistsView(View):
             self.__edit_button.hide()
 
         self.__playlists_widget = PlaylistsWidget(playlist_ids)
+        self.__playlists_widget.set_filter_func(self._filter_func)
         self.__playlists_widget.show()
         self.add(builder.get_object('widget'))
         self._viewport.add(self.__playlists_widget)
@@ -129,6 +128,15 @@ class PlaylistsView(View):
         """
         return [self.__playlists_widget]
 
+    def _on_search_changed(self, entry):
+        """
+            Update filter
+            @param entry as Gtk.Entry
+        """
+        self._filter = entry.get_text()
+        for box in self.__playlists_widget.boxes:
+            box.invalidate_filter()
+
     def _on_destroy(self, widget):
         """
             Disconnect signals
@@ -185,8 +193,9 @@ class PlaylistsView(View):
             self.__jump_button.set_sensitive(True)
             artists = ", ".join(Lp().player.current_track.artists)
             self.__jump_button.set_tooltip_markup(
-             "<b>%s</b>\n%s" % (escape(artists),
-                                escape(Lp().player.current_track.name)))
+             "<b>%s</b>\n%s" % (GLib.markup_escape_text(artists),
+                                GLib.markup_escape_text(
+                                              Lp().player.current_track.name)))
         else:
             self.__jump_button.set_sensitive(False)
             self.__jump_button.set_tooltip_text('')
