@@ -12,10 +12,9 @@
 
 from gi.repository import Gtk, GLib, Gdk, GObject, Pango
 
-from cgi import escape
 from gettext import gettext as _
 
-from lollypop.define import Lp, ArtSize, NextContext, Type
+from lollypop.define import Lp, ArtSize, Type
 from lollypop.define import WindowSize, Shuffle, Loading
 from lollypop.widgets_track import TracksWidget, TrackRow
 from lollypop.objects import Track, Album
@@ -24,17 +23,15 @@ from lollypop.pop_menu import AlbumMenuPopover, AlbumMenu
 from lollypop.pop_artwork import CoversPopover
 
 
-class AlbumWidget:
+class BaseWidget:
     """
         Base album widget
     """
 
-    def __init__(self, album_id, genre_ids=[]):
+    def __init__(self):
         """
             Init widget
         """
-        self._album = Album(album_id, genre_ids)
-        self._filter_ids = []
         self._selected = None
         self._loading = Loading.NONE
         self._cover = None
@@ -45,62 +42,10 @@ class AlbumWidget:
         self._show_overlay = False
         self._lock_overlay = False
         self._timeout_id = None
+        self.__parent_filter = False
         self._overlay_orientation = Gtk.Orientation.HORIZONTAL
         self._squared_class = "squared-icon"
         self._rounded_class = "rounded-icon"
-        self._scan_signal = Lp().scanner.connect('album-updated',
-                                                 self._on_album_updated)
-        self.connect('destroy', self.__on_destroy)
-
-    def set_cover(self):
-        """
-            Set cover for album if state changed
-        """
-        if self._cover is None:
-            return
-        surface = Lp().art.get_album_artwork(
-                            self._album,
-                            ArtSize.BIG,
-                            self._cover.get_scale_factor())
-        self._cover.set_from_surface(surface)
-        self._cover.set_size_request(100, 100)
-        if surface.get_height() > surface.get_width():
-            self._overlay_orientation = Gtk.Orientation.VERTICAL
-        else:
-            self._overlay_orientation = Gtk.Orientation.HORIZONTAL
-        del surface
-
-    def update_cover(self):
-        """
-            Update cover for album id id needed
-        """
-        if self._cover is None:
-            return
-        surface = Lp().art.get_album_artwork(
-                            self._album,
-                            ArtSize.BIG,
-                            self._cover.get_scale_factor())
-        self._cover.set_from_surface(surface)
-        if surface.get_height() > surface.get_width():
-            self._overlay_orientation = Gtk.Orientation.VERTICAL
-        else:
-            self._overlay_orientation = Gtk.Orientation.HORIZONTAL
-        del surface
-
-    def update_state(self):
-        """
-            Update widget state
-        """
-        if self._cover is None:
-            return
-        selected = self._album.id == Lp().player.current_track.album.id
-        if selected != self._selected:
-            if selected:
-                self._cover.get_style_context().add_class(
-                                                    'cover-frame-selected')
-            else:
-                self._cover.get_style_context().remove_class(
-                                                    'cover-frame-selected')
 
     def update_playing_indicator(self):
         """
@@ -121,21 +66,22 @@ class AlbumWidget:
         """
         self._loading = Loading.STOP
 
+    def set_filtered(self, b):
+        """
+            Set widget filtered
+        """
+        self.__parent_filter = b
+
     @property
-    def id(self):
-        """
-            Return album id for widget
-            @return album id as int
-        """
-        return self._album.id
-
-    def get_title(self):
+    def filter(self):
+        return ""
 
+    @property
+    def filtered(self):
         """
-            Return album title
-            @return album title as str
+            True if filtered by parent
         """
-        return self._album.name
+        return self.__parent_filter
 
     def lock_overlay(self, lock):
         """
@@ -181,6 +127,7 @@ class AlbumWidget:
            (set is True and Lp().player.locked):
             return
         self._show_overlay = set
+        self.emit('overlayed', set)
         if set:
             if self._play_button is not None:
                 self._play_button.set_opacity(1)
@@ -199,7 +146,7 @@ class AlbumWidget:
                                                            self._squared_class)
                 self._artwork_button.show()
             if self._action_button is not None:
-                self.__show_append(not Lp().player.has_album(self._album))
+                self._show_append(not Lp().player.has_album(self._album))
                 self._action_button.set_opacity(1)
                 self._action_button.get_style_context().add_class(
                                                        self._squared_class)
@@ -272,22 +219,7 @@ class AlbumWidget:
             @param: event as Gdk.Event
         """
         Lp().player.play_album(self._album)
-        self.__show_append(False)
-        return True
-
-    def _on_play_all_press_event(self, widget, event):
-        """
-            Play album with context
-            @param: widget as Gtk.EventBox
-            @param: event as Gdk.Event
-        """
-        self.__show_append(False)
-        if Lp().player.is_party:
-            Lp().player.set_party(False)
-        track = Track(self._album.track_ids[0])
-        Lp().player.load(track)
-        Lp().player.set_albums(track.id, self._filter_ids,
-                               self._album.genre_ids)
+        self._show_append(False)
         return True
 
     def _on_artwork_press_event(self, widget, event):
@@ -314,9 +246,7 @@ class AlbumWidget:
             if Lp().player.current_track.album.id == self._album.id:
                 # If not last album, skip it
                 if len(Lp().player.get_albums()) > 1:
-                    Lp().player.set_next_context(NextContext.START_NEW_ALBUM)
-                    Lp().player.set_next()
-                    Lp().player.next()
+                    Lp().player.skip_album()
                     Lp().player.remove_album(self._album)
                 # remove it and stop playback by going to next track
                 else:
@@ -325,13 +255,13 @@ class AlbumWidget:
                     Lp().player.next()
             else:
                 Lp().player.remove_album(self._album)
-            self.__show_append(True)
+            self._show_append(True)
         else:
             if Lp().player.is_playing() and not Lp().player.get_albums():
                 Lp().player.play_album(self._album)
             else:
                 Lp().player.add_album(self._album)
-            self.__show_append(False)
+            self._show_append(False)
         return True
 
     def _on_pop_cover_closed(self, widget):
@@ -342,21 +272,7 @@ class AlbumWidget:
         self._lock_overlay = False
         GLib.idle_add(self.show_overlay, False)
 
-    def _on_album_updated(self, scanner, album_id, destroy):
-        """
-            On album modified, disable it
-            @param scanner as CollectionScanner
-            @param album id as int
-            @param deleted as bool
-            @param destroy as bool
-        """
-        if self._album.id == album_id and destroy:
-            self.destroy()
-
-#######################
-# PRIVATE             #
-#######################
-    def __show_append(self, append):
+    def _show_append(self, append):
         """
             Show append button if append, else remove button
         """
@@ -369,14 +285,9 @@ class AlbumWidget:
                                                    Gtk.IconSize.BUTTON)
             self._action_event.set_tooltip_text(_("Remove"))
 
-    def __on_destroy(self, widget):
-        """
-            Disconnect signal
-            @param widget as Gtk.Widget
-        """
-        if self._scan_signal is not None:
-            Lp().scanner.disconnect(self._scan_signal)
-
+#######################
+# PRIVATE             #
+#######################
     def __on_enter_notify_timeout(self):
         """
             Show overlay buttons
@@ -386,10 +297,125 @@ class AlbumWidget:
             self._show_overlay_func(True)
 
 
+class AlbumWidget(BaseWidget):
+    """
+        Album widget
+    """
+
+    def __init__(self, album_id, genre_ids=[], artist_ids=[]):
+        """
+            Init Album widget
+        """
+        BaseWidget.__init__(self)
+        self._album = Album(album_id, genre_ids)
+        self._filter_ids = artist_ids
+        self.connect('destroy', self.__on_destroy)
+        self._scan_signal = Lp().scanner.connect('album-updated',
+                                                 self._on_album_updated)
+
+    @property
+    def album(self):
+        """
+            @return Album
+        """
+        return self._album
+
+    @property
+    def id(self):
+        """
+            Return widget id
+        """
+        return self._album.id
+
+    @property
+    def filter(self):
+        """
+            @return str
+        """
+        return " ".join([self._album.name]+self._album.artists)
+
+    def get_cover(self):
+        """
+            Get album cover
+            @return cover as Gtk.Image
+        """
+        return self._cover
+
+    def set_cover(self):
+        """
+            Set cover for album if state changed
+        """
+        if self._cover is None:
+            return
+        surface = Lp().art.get_album_artwork(
+                            self._album,
+                            ArtSize.BIG,
+                            self._cover.get_scale_factor())
+        self._cover.set_from_surface(surface)
+        self._cover.set_size_request(100, 100)
+        if surface.get_height() > surface.get_width():
+            self._overlay_orientation = Gtk.Orientation.VERTICAL
+        else:
+            self._overlay_orientation = Gtk.Orientation.HORIZONTAL
+        del surface
+
+    def update_cover(self):
+        """
+            Update cover for album id id needed
+        """
+        if self._cover is None:
+            return
+        surface = Lp().art.get_album_artwork(
+                            self._album,
+                            ArtSize.BIG,
+                            self._cover.get_scale_factor())
+        self._cover.set_from_surface(surface)
+        if surface.get_height() > surface.get_width():
+            self._overlay_orientation = Gtk.Orientation.VERTICAL
+        else:
+            self._overlay_orientation = Gtk.Orientation.HORIZONTAL
+        del surface
+
+    def update_state(self):
+        """
+            Update widget state
+        """
+        if self._cover is None:
+            return
+        selected = self._album.id == Lp().player.current_track.album.id
+        if selected != self._selected:
+            if selected:
+                self._cover.get_style_context().add_class(
+                                                    'cover-frame-selected')
+            else:
+                self._cover.get_style_context().remove_class(
+                                                    'cover-frame-selected')
+
+#######################
+# PROTECTED           #
+#######################
+    def _on_album_updated(self, scanner, album_id, destroy):
+        pass
+
+#######################
+# PRIVATE             #
+#######################
+    def __on_destroy(self, widget):
+        """
+            Disconnect signal
+            @param widget as Gtk.Widget
+        """
+        if self._scan_signal is not None:
+            Lp().scanner.disconnect(self._scan_signal)
+
+
 class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
     """
         Album widget showing cover, artist and title
     """
+    __gsignals__ = {
+        'overlayed': (GObject.SignalFlags.RUN_FIRST, None, (bool,))
+    }
 
     def __init__(self, album_id, genre_ids, artist_ids):
         """
@@ -402,8 +428,7 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         Gtk.FlowBoxChild.__init__(self)
         self.set_size_request(ArtSize.BIG, ArtSize.BIG)
         self.get_style_context().add_class('loading')
-        AlbumWidget.__init__(self, album_id, genre_ids)
-        self._filter_ids = artist_ids
+        AlbumWidget.__init__(self, album_id, genre_ids, artist_ids)
 
     def populate(self):
         """
@@ -420,7 +445,10 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         self.__title_label = Gtk.Label()
         self.__title_label.set_ellipsize(Pango.EllipsizeMode.END)
         self.__title_label.set_property('halign', Gtk.Align.CENTER)
-        self.__title_label.set_markup("<b>"+escape(self._album.name)+"</b>")
+        self.__title_label.set_markup("<b>" +
+                                      GLib.markup_escape_text(
+                                                            self._album.name) +
+                                      "</b>")
         self.__artist_label = Gtk.Label()
         self.__artist_label.set_ellipsize(Pango.EllipsizeMode.END)
         self.__artist_label.set_property('halign', Gtk.Align.CENTER)
@@ -461,21 +489,6 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             self._cover.get_style_context().add_class(
                                                 'cover-frame-youtube')
 
-    @property
-    def id(self):
-        """
-            Return album id
-            @return int
-        """
-        return self._album.id
-
-    def get_cover(self):
-        """
-            Get album cover
-            @return cover as Gtk.Image
-        """
-        return self._cover
-
     def do_get_preferred_width(self):
         """
             Return preferred width
@@ -516,7 +529,7 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             self._play_all_event.set_property('halign', Gtk.Align.END)
             self._play_all_event.connect('realize', self._on_eventbox_realize)
             self._play_all_event.connect('button-press-event',
-                                         self._on_play_all_press_event)
+                                         self.__on_play_all_press_event)
             self._play_all_button = Gtk.Image.new()
             self._play_all_button.set_opacity(0)
             # Artwork button
@@ -584,9 +597,42 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             self._artwork_button.destroy()
             self._artwork_button = None
 
+    def _on_album_updated(self, scanner, album_id, destroy):
+        """
+            On album modified, disable it
+            @param scanner as CollectionScanner
+            @param album id as int
+            @param deleted as bool
+            @param destroy as bool
+        """
+        if self._album.id == album_id and destroy:
+            self.destroy()
+
 #######################
 # PRIVATE             #
 #######################
+    def __on_play_all_press_event(self, widget, event):
+        """
+            Play album with context
+            @param: widget as Gtk.EventBox
+            @param: event as Gdk.Event
+        """
+        self._show_append(False)
+        if Lp().player.is_party:
+            Lp().player.set_party(False)
+        Lp().player.clear_albums()
+        track = Track(self._album.track_ids[0])
+        if Lp().window.view.filtered:
+            # Here we need to get ids from parent as view may be filtered
+            for child in self.get_parent().get_children():
+                if not child.filtered:
+                    Lp().player.add_album(child.album)
+        else:
+            Lp().player.set_albums(track.id, self._filter_ids,
+                                   self._album.genre_ids)
+        Lp().player.load(track)
+        return True
+
     def _on_query_tooltip(self, eventbox, x, y, keyboard, tooltip):
         """
             Show tooltip if needed
@@ -603,10 +649,11 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
                 artist_text = self.__artist_label.get_text()
                 if artist_text:
                     text = "<b>%s</b> - %s" % (
-                                        escape(artist_text),
-                                        escape(self.__title_label.get_text()))
+                        GLib.markup_escape_text(artist_text),
+                        GLib.markup_escape_text(self.__title_label.get_text()))
                 else:
-                    text = escape(self.__title_label.get_text())
+                    text = GLib.markup_escape_text(
+                                                 self.__title_label.get_text())
                 eventbox.set_tooltip_markup(text)
                 break
 
@@ -616,7 +663,8 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         Widget with cover and tracks
     """
     __gsignals__ = {
-        'populated': (GObject.SignalFlags.RUN_FIRST, None, ())
+        'populated': (GObject.SignalFlags.RUN_FIRST, None, ()),
+        'overlayed': (GObject.SignalFlags.RUN_FIRST, None, (bool,))
     }
 
     def __init__(self, album_id, genre_ids, artist_ids, show_cover):
@@ -629,7 +677,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
             @param show cover as bool
         """
         Gtk.Bin.__init__(self)
-        AlbumWidget.__init__(self, album_id, genre_ids)
+        AlbumWidget.__init__(self, album_id, genre_ids, artist_ids)
         self._album.set_artists(artist_ids)
         self.__width = None
         # Cover + rating + spacing
@@ -641,7 +689,6 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         # Discs to load, will be emptied
         self.__discs = self._album.discs
         self.__locked_widget_right = True
-        self._filter_ids = artist_ids
         self.set_property('height-request', self.__height)
         self.connect('size-allocate', self.__on_size_allocate)
         builder = Gtk.Builder()
@@ -807,6 +854,27 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
                         return child.translate_coordinates(parent, 0, 0)[1]
         return None
 
+    def set_filter_func(self, func):
+        """
+            Set filter function
+        """
+        for widget in self._tracks_left.values():
+            widget.set_filter_func(func)
+        for widget in self._tracks_right.values():
+            widget.set_filter_func(func)
+
+    @property
+    def boxes(self):
+        """
+            @return [Gtk.ListBox]
+        """
+        boxes = []
+        for widget in self._tracks_left.values():
+            boxes.append(widget)
+        for widget in self._tracks_right.values():
+            boxes.append(widget)
+        return boxes
+
     @property
     def requested_height(self):
         """
@@ -1060,12 +1128,6 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
                 Lp().player.del_from_queue(track_id)
             else:
                 Lp().player.append_to_queue(track_id)
-        # Play track with no album, force repeat on track
-        elif self._button_state & Gdk.ModifierType.SHIFT_MASK:
-            Lp().player.clear_albums()
-            self.__show_spinner(widget, track_id)
-            track = Track(track_id)
-            Lp().player.load(track)
         else:
             # Do not modify album list if in party mode
             if not Lp().player.is_party:
@@ -1081,7 +1143,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
             track = Track(track_id)
             Lp().player.load(track)
             if self._button_state & Gdk.ModifierType.CONTROL_MASK:
-                Lp().player.set_next_context(NextContext.STOP_TRACK)
+                Lp().player.skip_album()
 
     def __on_button_press_event(self, widget, event):
         """
