@@ -13,13 +13,14 @@
 from gi.repository import Gtk, Gdk, GdkPixbuf, GLib, Gio
 
 from threading import Thread
-from cgi import escape
+from gettext import gettext as _
 
 try:
     from lollypop.wikipedia import Wikipedia
 except:
     pass
 from lollypop.define import Lp
+from lollypop.utils import get_network_available
 from lollypop.cache import InfoCache
 
 
@@ -45,6 +46,7 @@ class InfoContent(Gtk.Stack):
         self.__image = builder.get_object('image')
         self._menu_found = builder.get_object('menu-found')
         self._menu_not_found = builder.get_object('menu-not-found')
+        self.__error = builder.get_object('error')
         self.add_named(builder.get_object('widget'), 'widget')
         self.add_named(builder.get_object('notfound'), 'notfound')
         self._spinner = builder.get_object('spinner')
@@ -121,6 +123,14 @@ class InfoContent(Gtk.Stack):
         """
             Show not found child
         """
+        if get_network_available():
+            error = _("No information for this artist")
+        else:
+            error = _("Network access disabled")
+        self.__error.set_markup(
+                       "<span font_weight='bold' size='xx-large'>" +
+                       error +
+                       "</span>")
         self.set_visible_child_name('notfound')
 
 #######################
@@ -133,7 +143,8 @@ class InfoContent(Gtk.Stack):
             @param data as Gio.MemoryInputStream
         """
         if content is not None:
-            self.__content.set_markup(escape(content.decode('utf-8')))
+            self.__content.set_markup(
+                              GLib.markup_escape_text(content.decode('utf-8')))
             if stream is not None:
                 scale = self.__image.get_scale_factor()
                 # Will happen if cache is broken or when reading empty files
@@ -189,7 +200,7 @@ class WikipediaContent(InfoContent):
             GLib.idle_add(self.set_visible_child_name, 'spinner')
             self._spinner.start()
             self.__load_page_content(artist)
-        else:
+        elif get_network_available():
             t = Thread(target=self.__setup_menu,
                        args=(self._artist, self.__album))
             t.daemon = True
@@ -209,10 +220,12 @@ class WikipediaContent(InfoContent):
         """
             Show not found child
         """
-        self.set_visible_child_name('notfound')
-        t = Thread(target=self.__setup_menu, args=(self._artist, self.__album))
-        t.daemon = True
-        t.start()
+        InfoContent.__on_not_found(self)
+        if get_network_available():
+            t = Thread(target=self.__setup_menu,
+                       args=(self._artist, self.__album))
+            t.daemon = True
+            t.start()
 
 #######################
 # PRIVATE             #
@@ -231,10 +244,11 @@ class WikipediaContent(InfoContent):
         if not self._stop:
             InfoContent.set_content(self, self._artist, content,
                                     url, 'wikipedia')
-            t = Thread(target=self.__setup_menu,
-                       args=(self._artist, self.__album))
-            t.daemon = True
-            t.start()
+            if get_network_available():
+                t = Thread(target=self.__setup_menu,
+                           args=(self._artist, self.__album))
+                t.daemon = True
+                t.start()
 
     def __setup_menu(self, artist, album):
         """
