@@ -13,7 +13,6 @@
 from gi.repository import Gtk, GLib, Gdk, Pango, GObject
 
 from threading import Thread
-from cgi import escape
 from gettext import gettext as _
 
 from lollypop.define import Lp, Type, WindowSize, Loading
@@ -47,10 +46,10 @@ class PlaylistsWidget(Gtk.Grid):
         # Used to block widget2 populate while showing one column
         self.__locked_widget_right = True
 
-        self.__box = Gtk.Grid()
-        self.__box.set_vexpand(True)
-        self.__box.set_column_homogeneous(True)
-        self.__box.show()
+        self.__grid = Gtk.Grid()
+        self.__grid.set_vexpand(True)
+        self.__grid.set_column_homogeneous(True)
+        self.__grid.show()
 
         self.connect('size-allocate', self.__on_size_allocate)
 
@@ -70,7 +69,7 @@ class PlaylistsWidget(Gtk.Grid):
         self.drag_dest_add_text_targets()
         self.connect('drag-data-received', self.__on_drag_data_received)
 
-        self.add(self.__box)
+        self.add(self.__grid)
 
     @property
     def id(self):
@@ -80,6 +79,20 @@ class PlaylistsWidget(Gtk.Grid):
         """
         return Type.PLAYLISTS
 
+    @property
+    def boxes(self):
+        """
+            @return [Gtk.ListBox]
+        """
+        return [self.__tracks_widget_left, self.__tracks_widget_right]
+
+    def set_filter_func(self, func):
+        """
+            Set filter function
+        """
+        self.__tracks_widget_left.set_filter_func(func)
+        self.__tracks_widget_right.set_filter_func(func)
+
     def show_overlay(self, bool):
         """
             No overlay here now
@@ -114,7 +127,7 @@ class PlaylistsWidget(Gtk.Grid):
         for child in self.__tracks_widget_left.get_children() + \
                 self.__tracks_widget_right.get_children():
             if child.id == Lp().player.current_track.id:
-                ordinate = child.translate_coordinates(self.__box, 0, 0)[1]
+                ordinate = child.translate_coordinates(self.__grid, 0, 0)[1]
         return ordinate
 
     def populate_list_left(self, tracks, pos):
@@ -334,7 +347,7 @@ class PlaylistsWidget(Gtk.Grid):
                 break
         src_track = Track(src)
         prev_track = Track()
-        name = escape(src_track.name)
+        name = GLib.markup_escape_text(src_track.name)
         index = 0
         # Get previous track
         if dst != -1:
@@ -353,8 +366,9 @@ class PlaylistsWidget(Gtk.Grid):
             if (src_track.album.artist_id == Type.COMPILATIONS or
                     len(src_track.artist_ids) > 1 or
                     src_track.album.artist_id not in src_track.artist_ids):
-                name = "<b>%s</b>\n%s" % (escape(", ".join(src_track.artists)),
-                                          name)
+                name = "<b>%s</b>\n%s" % (
+                         GLib.markup_escape_text(", ".join(src_track.artists)),
+                         name)
             self.__tracks_left.insert(index, src_track.id)
         row = PlaylistRow(src_track.id,
                           index,
@@ -434,20 +448,20 @@ class PlaylistsWidget(Gtk.Grid):
         redraw = False
         if allocation.width < WindowSize.MONSTER or\
                 not Lp().settings.get_value('split-view'):
-            self.__box.set_property('valign', Gtk.Align.START)
+            self.__grid.set_property('valign', Gtk.Align.START)
             orientation = Gtk.Orientation.VERTICAL
         else:
-            self.__box.set_property('valign', Gtk.Align.FILL)
+            self.__grid.set_property('valign', Gtk.Align.FILL)
             orientation = Gtk.Orientation.HORIZONTAL
         if orientation != self.__orientation:
             self.__orientation = orientation
             redraw = True
-        self.__box.set_orientation(orientation)
+        self.__grid.set_orientation(orientation)
         if redraw:
-            for child in self.__box.get_children():
-                self.__box.remove(child)
-            GLib.idle_add(self.__box.add, self.__tracks_widget_left)
-            GLib.idle_add(self.__box.add, self.__tracks_widget_right)
+            for child in self.__grid.get_children():
+                self.__grid.remove(child)
+            GLib.idle_add(self.__grid.add, self.__tracks_widget_left)
+            GLib.idle_add(self.__grid.add, self.__tracks_widget_right)
         self.__update_headers()
 
     def __on_activated(self, widget, track_id):
@@ -734,7 +748,7 @@ class PlaylistsManagerWidget(Gtk.Bin):
             @param path as str representation of Gtk.TreePath
         """
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(False)
+        Lp().window.enable_global_shortcuts(False)
 
     def __on_playlist_editing_cancel(self, widget):
         """
@@ -742,7 +756,7 @@ class PlaylistsManagerWidget(Gtk.Bin):
             @param widget as cell renderer
         """
         # FIXME Not needed with GTK >= 3.18
-        Lp().window.enable_global_shorcuts(True)
+        Lp().window.enable_global_shortcuts(True)
 
     def __on_column0_clicked(self, column):
         """
@@ -927,8 +941,8 @@ class PlaylistEditWidget(Gtk.Bin):
                 artists = ", ".join(track.album.artists)
             self.__model.append([track.album.id,
                                 "<b>%s</b>\n%s" % (
-                                   escape(artists),
-                                   escape(track.name)),
+                                   GLib.markup_escape_text(artists),
+                                   GLib.markup_escape_text(track.name)),
                                  'user-trash-symbolic', track.id])
             GLib.idle_add(self.__append_track, track_ids)
         else:
