@@ -10,20 +10,23 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, Pango
+from gi.repository import Gtk, Pango, GObject
 
 from gettext import gettext as _
 
 from lollypop.define import Lp, ArtSize, Type
 from lollypop.objects import Track
-from lollypop.widgets_album import AlbumWidget
+from lollypop.widgets_album import BaseWidget
 from lollypop.pop_radio import RadioPopover
 
 
-class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
+class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
     """
         Widget with radio cover and title
     """
+    __gsignals__ = {
+        'overlayed': (GObject.SignalFlags.RUN_FIRST, None, (bool,))
+    }
 
     def __init__(self, name, radios_manager):
         """
@@ -32,12 +35,9 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             @param radios_manager as RadiosManager
         """
         Gtk.FlowBoxChild.__init__(self)
+        BaseWidget.__init__(self)
         self.get_style_context().add_class('loading')
-        self._name = name
-        self._cover = None
-        self._lock_overlay = False
-        self._show_overlay = False
-        self._timeout_id = None
+        self.__name = name
         self.__radios_manager = radios_manager
 
     def populate(self):
@@ -45,7 +45,6 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             Init widget content
         """
         self.get_style_context().remove_class('loading')
-        AlbumWidget.__init__(self, None)
         self._widget = Gtk.EventBox()
         self._widget.connect('enter-notify-event', self._on_enter_notify)
         self._widget.connect('leave-notify-event', self._on_leave_notify)
@@ -55,7 +54,7 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         self.__title_label = Gtk.Label()
         self.__title_label.set_ellipsize(Pango.EllipsizeMode.END)
         self.__title_label.set_property('halign', Gtk.Align.CENTER)
-        self.__title_label.set_text(self._name)
+        self.__title_label.set_text(self.__name)
         self.__title_label.set_property('has-tooltip', True)
         self.__title_label.connect('query-tooltip', self._on_query_tooltip)
         self._overlay = Gtk.Overlay()
@@ -89,6 +88,20 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         """
         return Type.RADIOS
 
+    @property
+    def filter(self):
+        """
+            @Return filter as str
+        """
+        return self.__name
+
+    @property
+    def title(self):
+        """
+            @Return title as str
+        """
+        return self.__name
+
     def do_get_preferred_width(self):
         """
             Return preferred width
@@ -103,16 +116,9 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             Set radio name
             @param name as string
         """
-        self._name = name
+        self.__name = name
         self.__title_label.set_label(name)
 
-    def get_name(self):
-        """
-            Return radio name
-            @return name as string
-        """
-        return self._name
-
     def set_cover(self):
         """
             Set cover for album if state changed
@@ -120,7 +126,7 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         if self._cover is None:
             return
         surface = Lp().art.get_radio_artwork(
-                    self._name,
+                    self.__name,
                     ArtSize.BIG,
                     self._cover.get_scale_factor())
         self._cover.set_from_surface(surface)
@@ -133,7 +139,7 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         if self._cover is None:
             return
         surface = Lp().art.get_radio_artwork(
-                    self._name,
+                    self.__name,
                     ArtSize.BIG,
                     self._cover.get_scale_factor())
         self._cover.set_from_surface(surface)
@@ -146,7 +152,7 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         if self._cover is None:
             return
         selected = Lp().player.current_track.id == Type.RADIOS and\
-            self._name == Lp().player.current_track.album_artists[0]
+            self.__name == Lp().player.current_track.album_artists[0]
         if selected:
             self._overlay.get_style_context().add_class(
                                                     'cover-frame-selected')
@@ -202,9 +208,9 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             self._overlay.add_overlay(self._play_event)
             self._overlay.add_overlay(self._artwork_event)
             self._overlay.show_all()
-            AlbumWidget._show_overlay_func(self, True)
+            BaseWidget._show_overlay_func(self, True)
         else:
-            AlbumWidget._show_overlay_func(self, False)
+            BaseWidget._show_overlay_func(self, False)
             self._play_event.destroy()
             self._play_event = None
             self._play_button.destroy()
@@ -238,10 +244,10 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             @param: widget as Gtk.EventBox
             @param: event as Gdk.Event
         """
-        url = self.__radios_manager.get_url(self._name)
+        url = self.__radios_manager.get_url(self.__name)
         if url:
             track = Track()
-            track.set_radio(self._name, url)
+            track.set_radio(self.__name, url)
             Lp().player.load(track)
 
     def _on_edit_press_event(self, widget, event):
@@ -250,7 +256,7 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             @param: widget as Gtk.EventBox
             @param: event as Gdk.Event
         """
-        popover = RadioPopover(self._name, self.__radios_manager)
+        popover = RadioPopover(self.__name, self.__radios_manager)
         popover.set_relative_to(widget)
         popover.connect('closed', self._on_pop_cover_closed)
         self._lock_overlay = True
