@@ -12,8 +12,6 @@
 
 from gi.repository import GObject, Gtk, Gdk, Pango, GLib, Gst
 
-from cgi import escape
-
 from lollypop.define import Lp, ArtSize, Type
 from lollypop.pop_menu import TrackMenuPopover, TrackMenu
 from lollypop.widgets_indicator import IndicatorWidget
@@ -56,7 +54,7 @@ class Row(Gtk.ListBoxRow):
         self._title_label.set_property('halign', Gtk.Align.START)
         self._title_label.set_ellipsize(Pango.EllipsizeMode.END)
         if self._track.non_album_artists:
-            self._artists_label = Gtk.Label.new(escape(
+            self._artists_label = Gtk.Label.new(GLib.markup_escape_text(
                                      ", ".join(self._track.non_album_artists)))
             self._artists_label.set_use_markup(True)
             self._artists_label.set_property('has-tooltip', True)
@@ -289,7 +287,7 @@ class Row(Gtk.ListBoxRow):
         layout = widget.get_layout()
         label = widget.get_text()
         if layout.is_ellipsized():
-            text = "%s" % (escape(label))
+            text = "%s" % (GLib.markup_escape_text(label))
         widget.set_tooltip_markup(text)
 
 
@@ -309,6 +307,7 @@ class PlaylistRow(Row):
             @param show headers as bool
         """
         Row.__init__(self, rowid, num)
+        self.__parent_filter = False
         self.__show_headers = show_headers
         self._indicator.set_margin_start(5)
         self._row_widget.set_margin_start(5)
@@ -339,7 +338,8 @@ class PlaylistRow(Row):
             self.__album_artist_label = Gtk.Label()
             self.__album_artist_label.set_markup(
                                  "<b>" +
-                                 escape(", ".join(self._track.album.artists)) +
+                                 GLib.markup_escape_text(
+                                       ", ".join(self._track.album.artists)) +
                                  "</b>")
             self.__album_artist_label.set_ellipsize(Pango.EllipsizeMode.END)
             self.__album_artist_label.get_style_context().add_class(
@@ -373,6 +373,28 @@ class PlaylistRow(Row):
         self.connect('drag-motion', self.__on_drag_motion)
         self.connect('drag-leave', self.__on_drag_leave)
 
+    @property
+    def filter(self):
+        """
+            @return str
+        """
+        return " ".join(self._track.album.artists + self._track.artists +
+                        [self._track.name] +
+                        [self._track.album.name])
+
+    def set_filtered(self, b):
+        """
+            Set widget filtered
+        """
+        self.__parent_filter = b
+
+    @property
+    def filtered(self):
+        """
+            True if filtered by parent
+        """
+        return self.__parent_filter
+
     def show_headers(self, show):
         """
             Show header
@@ -503,10 +525,30 @@ class TrackRow(Row):
             @param num as int
         """
         Row.__init__(self, rowid, num)
+        self.__parent_filter = False
         self._grid.insert_column(0)
         self._grid.attach(self._indicator, 0, 0, 1, 1)
         self.show_all()
 
+    @property
+    def filter(self):
+        """
+            @return str
+        """
+        return self._track.name
+
+    def set_filtered(self, b):
+        """
+            Set widget filtered
+        """
+        self.__parent_filter = b
+
+    @property
+    def filtered(self):
+        """
+            True if filtered by parent
+        """
+        return self.__parent_filter
 #######################
 # PRIVATE             #
 #######################
